/****************************************************************************
** Meta object code from reading C++ file 'mainwindow.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "src/mainwindow.h"
#include <QtGui/qtextcursor.h>
#include <QtNetwork/QSslError>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'mainwindow.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13QvkMainWindowE_t {};
} // unnamed namespace

template <> constexpr inline auto QvkMainWindow::qt_create_metaobjectdata<qt_meta_tag_ZN13QvkMainWindowE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QvkMainWindow",
        "signal_close",
        "",
        "signal_newVideoFilename",
        "signal_resizeEvent",
        "QResizeEvent*",
        "event",
        "slot_preStart",
        "slot_Start",
        "slot_preStop",
        "slot_Stop",
        "slot_Pause",
        "slot_Continue",
        "slot_Play",
        "slot_Folder",
        "slot_logFolder",
        "slot_screenCountChanged",
        "slot_screenCountChangedArea",
        "stringText",
        "stringData",
        "slot_newVideoPath",
        "slot_videoFileSystemWatcherSetButtons",
        "slot_videoFileSystemWatcherSetNewPath",
        "slot_startCounter",
        "value",
        "slot_comboBoxScreencastScreenCountdown",
        "slot_videoCodecChanged",
        "codec",
        "slot_framesReset",
        "slot_x264Reset",
        "slot_openh264Reset",
        "slot_GstreamerDebugLevel",
        "slot_GstreamerDebugLevelDialog",
        "slot_GstreamerOpenFolder",
        "slot_StartTimer",
        "slot_startTime",
        "slot_areaSetResolution",
        "slot_IfStartAudioCodecWidgetsSetEnabled",
        "slot_IfStopAudioCodecWidgetsSetDisabled",
        "slot_setMaxFPS",
        "slot_cancel",
        "slot_haveAudioDeviceSelected",
        "bo",
        "slot_comboBoxOpenh264Profile",
        "list",
        "slot_disableShowclickHalo",
        "slot_currentTextChangedToGIF",
        "slot_languageChanged",
        "slot_darkMode",
        "slot_profileSave",
        "slot_profileLoad",
        "index",
        "slot_profileNew",
        "slot_profileDelete",
        "slot_log_refresh"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'signal_close'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'signal_newVideoFilename'
        QtMocHelpers::SignalData<void(QString)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Signal 'signal_resizeEvent'
        QtMocHelpers::SignalData<void(QResizeEvent *)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Slot 'slot_preStart'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slot_Start'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slot_preStop'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slot_Stop'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slot_Pause'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slot_Continue'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slot_Play'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slot_Folder'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slot_logFolder'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slot_screenCountChanged'
        QtMocHelpers::SlotData<void(QString, QString)>(16, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 2 }, { QMetaType::QString, 2 },
        }}),
        // Slot 'slot_screenCountChangedArea'
        QtMocHelpers::SlotData<void(QString, QString)>(17, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 18 }, { QMetaType::QString, 19 },
        }}),
        // Slot 'slot_newVideoPath'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slot_videoFileSystemWatcherSetButtons'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slot_videoFileSystemWatcherSetNewPath'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slot_startCounter'
        QtMocHelpers::SlotData<void(bool)>(23, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 24 },
        }}),
        // Slot 'slot_comboBoxScreencastScreenCountdown'
        QtMocHelpers::SlotData<void(bool)>(25, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'slot_videoCodecChanged'
        QtMocHelpers::SlotData<void(QString)>(26, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 27 },
        }}),
        // Slot 'slot_framesReset'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slot_x264Reset'
        QtMocHelpers::SlotData<void()>(29, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slot_openh264Reset'
        QtMocHelpers::SlotData<void()>(30, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slot_GstreamerDebugLevel'
        QtMocHelpers::SlotData<void(bool)>(31, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'slot_GstreamerDebugLevelDialog'
        QtMocHelpers::SlotData<void(bool)>(32, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'slot_GstreamerOpenFolder'
        QtMocHelpers::SlotData<void(bool)>(33, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'slot_StartTimer'
        QtMocHelpers::SlotData<void(bool)>(34, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 24 },
        }}),
        // Slot 'slot_startTime'
        QtMocHelpers::SlotData<void()>(35, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slot_areaSetResolution'
        QtMocHelpers::SlotData<void(QString)>(36, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 24 },
        }}),
        // Slot 'slot_IfStartAudioCodecWidgetsSetEnabled'
        QtMocHelpers::SlotData<void()>(37, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slot_IfStopAudioCodecWidgetsSetDisabled'
        QtMocHelpers::SlotData<void()>(38, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slot_setMaxFPS'
        QtMocHelpers::SlotData<void(int)>(39, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'slot_cancel'
        QtMocHelpers::SlotData<void(bool)>(40, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 24 },
        }}),
        // Slot 'slot_haveAudioDeviceSelected'
        QtMocHelpers::SlotData<void(bool)>(41, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 42 },
        }}),
        // Slot 'slot_comboBoxOpenh264Profile'
        QtMocHelpers::SlotData<void(QStringList)>(43, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QStringList, 44 },
        }}),
        // Slot 'slot_disableShowclickHalo'
        QtMocHelpers::SlotData<void(bool)>(45, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 42 },
        }}),
        // Slot 'slot_currentTextChangedToGIF'
        QtMocHelpers::SlotData<void(QString)>(46, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 24 },
        }}),
        // Slot 'slot_languageChanged'
        QtMocHelpers::SlotData<void(int)>(47, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'slot_darkMode'
        QtMocHelpers::SlotData<void(bool)>(48, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 42 },
        }}),
        // Slot 'slot_profileSave'
        QtMocHelpers::SlotData<void(bool)>(49, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 42 },
        }}),
        // Slot 'slot_profileLoad'
        QtMocHelpers::SlotData<void(int)>(50, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 51 },
        }}),
        // Slot 'slot_profileNew'
        QtMocHelpers::SlotData<void(bool)>(52, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 42 },
        }}),
        // Slot 'slot_profileDelete'
        QtMocHelpers::SlotData<void(bool)>(53, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 42 },
        }}),
        // Slot 'slot_log_refresh'
        QtMocHelpers::SlotData<void()>(54, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<QvkMainWindow, qt_meta_tag_ZN13QvkMainWindowE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject QvkMainWindow::staticMetaObject = { {
    QMetaObject::SuperData::link<QMainWindow::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13QvkMainWindowE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13QvkMainWindowE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13QvkMainWindowE_t>.metaTypes,
    nullptr
} };

void QvkMainWindow::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QvkMainWindow *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->signal_close(); break;
        case 1: _t->signal_newVideoFilename((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->signal_resizeEvent((*reinterpret_cast<std::add_pointer_t<QResizeEvent*>>(_a[1]))); break;
        case 3: _t->slot_preStart(); break;
        case 4: _t->slot_Start(); break;
        case 5: _t->slot_preStop(); break;
        case 6: _t->slot_Stop(); break;
        case 7: _t->slot_Pause(); break;
        case 8: _t->slot_Continue(); break;
        case 9: _t->slot_Play(); break;
        case 10: _t->slot_Folder(); break;
        case 11: _t->slot_logFolder(); break;
        case 12: _t->slot_screenCountChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 13: _t->slot_screenCountChangedArea((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 14: _t->slot_newVideoPath(); break;
        case 15: _t->slot_videoFileSystemWatcherSetButtons(); break;
        case 16: _t->slot_videoFileSystemWatcherSetNewPath(); break;
        case 17: _t->slot_startCounter((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 18: _t->slot_comboBoxScreencastScreenCountdown((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 19: _t->slot_videoCodecChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 20: _t->slot_framesReset(); break;
        case 21: _t->slot_x264Reset(); break;
        case 22: _t->slot_openh264Reset(); break;
        case 23: _t->slot_GstreamerDebugLevel((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 24: _t->slot_GstreamerDebugLevelDialog((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 25: _t->slot_GstreamerOpenFolder((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 26: _t->slot_StartTimer((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 27: _t->slot_startTime(); break;
        case 28: _t->slot_areaSetResolution((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 29: _t->slot_IfStartAudioCodecWidgetsSetEnabled(); break;
        case 30: _t->slot_IfStopAudioCodecWidgetsSetDisabled(); break;
        case 31: _t->slot_setMaxFPS((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 32: _t->slot_cancel((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 33: _t->slot_haveAudioDeviceSelected((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 34: _t->slot_comboBoxOpenh264Profile((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 35: _t->slot_disableShowclickHalo((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 36: _t->slot_currentTextChangedToGIF((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 37: _t->slot_languageChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 38: _t->slot_darkMode((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 39: _t->slot_profileSave((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 40: _t->slot_profileLoad((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 41: _t->slot_profileNew((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 42: _t->slot_profileDelete((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 43: _t->slot_log_refresh(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QvkMainWindow::*)()>(_a, &QvkMainWindow::signal_close, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QvkMainWindow::*)(QString )>(_a, &QvkMainWindow::signal_newVideoFilename, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (QvkMainWindow::*)(QResizeEvent * )>(_a, &QvkMainWindow::signal_resizeEvent, 2))
            return;
    }
}

const QMetaObject *QvkMainWindow::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QvkMainWindow::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13QvkMainWindowE_t>.strings))
        return static_cast<void*>(this);
    return QMainWindow::qt_metacast(_clname);
}

int QvkMainWindow::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QMainWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 44)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 44;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 44)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 44;
    }
    return _id;
}

// SIGNAL 0
void QvkMainWindow::signal_close()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void QvkMainWindow::signal_newVideoFilename(QString _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void QvkMainWindow::signal_resizeEvent(QResizeEvent * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}
QT_WARNING_POP
