/****************************************************************************
** Meta object code from reading C++ file 'QvkGlobalShortcut.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "src/QvkGlobalShortcut/QvkGlobalShortcut.h"
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'QvkGlobalShortcut.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN17QvkGlobalShortcutE_t {};
} // unnamed namespace

template <> constexpr inline auto QvkGlobalShortcut::qt_create_metaobjectdata<qt_meta_tag_ZN17QvkGlobalShortcutE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QvkGlobalShortcut",
        "signal_shortcutSystray",
        "",
        "slot_startStop",
        "slot_checkbox_shortcut_start_clicked",
        "value",
        "slot_checkbox_shortcut_start_currentIndexChanged",
        "slot_toolButton_shortcut_start_reset",
        "slot_checkbox_shortcut_pause_clicked",
        "slot_checkbox_shortcut_pause_currentIndexChanged",
        "slot_toolButton_shortcut_pause_reset",
        "slot_checkbox_shortcut_magnification_clicked",
        "slot_checkbox_shortcut_magnification_currentIndexChanged",
        "slot_toolButton_shortcut_magnification_reset",
        "slot_checkbox_shortcut_camera_clicked",
        "slot_checkbox_shortcut_camera_currentIndexChanged",
        "slot_toolButton_shortcut_camera_reset",
        "slot_checkbox_shortcut_showclick_clicked",
        "slot_checkbox_shortcut_showclick_currentIndexChanged",
        "slot_toolButton_shortcut_showclick_reset",
        "slot_checkbox_shortcut_halo_clicked",
        "slot_checkbox_shortcut_halo_currentIndexChanged",
        "slot_toolButton_shortcut_halo_reset",
        "slot_checkbox_shortcut_snapshot_clicked",
        "slot_checkbox_shortcut_snapshot_currentIndexChanged",
        "slot_toolButton_shortcut_snapshot_reset",
        "slot_checkbox_camera_click",
        "slot_pauseContinue",
        "slot_setOrUnsetShortcut"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'signal_shortcutSystray'
        QtMocHelpers::SignalData<void(QString, QString)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 }, { QMetaType::QString, 2 },
        }}),
        // Slot 'slot_startStop'
        QtMocHelpers::SlotData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slot_checkbox_shortcut_start_clicked'
        QtMocHelpers::SlotData<void(bool)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 5 },
        }}),
        // Slot 'slot_checkbox_shortcut_start_currentIndexChanged'
        QtMocHelpers::SlotData<void(int)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 5 },
        }}),
        // Slot 'slot_toolButton_shortcut_start_reset'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slot_checkbox_shortcut_pause_clicked'
        QtMocHelpers::SlotData<void(bool)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 5 },
        }}),
        // Slot 'slot_checkbox_shortcut_pause_currentIndexChanged'
        QtMocHelpers::SlotData<void(int)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 5 },
        }}),
        // Slot 'slot_toolButton_shortcut_pause_reset'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slot_checkbox_shortcut_magnification_clicked'
        QtMocHelpers::SlotData<void(bool)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 5 },
        }}),
        // Slot 'slot_checkbox_shortcut_magnification_currentIndexChanged'
        QtMocHelpers::SlotData<void(int)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 5 },
        }}),
        // Slot 'slot_toolButton_shortcut_magnification_reset'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slot_checkbox_shortcut_camera_clicked'
        QtMocHelpers::SlotData<void(bool)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 5 },
        }}),
        // Slot 'slot_checkbox_shortcut_camera_currentIndexChanged'
        QtMocHelpers::SlotData<void(int)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 5 },
        }}),
        // Slot 'slot_toolButton_shortcut_camera_reset'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slot_checkbox_shortcut_showclick_clicked'
        QtMocHelpers::SlotData<void(bool)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 5 },
        }}),
        // Slot 'slot_checkbox_shortcut_showclick_currentIndexChanged'
        QtMocHelpers::SlotData<void(int)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 5 },
        }}),
        // Slot 'slot_toolButton_shortcut_showclick_reset'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slot_checkbox_shortcut_halo_clicked'
        QtMocHelpers::SlotData<void(bool)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 5 },
        }}),
        // Slot 'slot_checkbox_shortcut_halo_currentIndexChanged'
        QtMocHelpers::SlotData<void(int)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 5 },
        }}),
        // Slot 'slot_toolButton_shortcut_halo_reset'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slot_checkbox_shortcut_snapshot_clicked'
        QtMocHelpers::SlotData<void(bool)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 5 },
        }}),
        // Slot 'slot_checkbox_shortcut_snapshot_currentIndexChanged'
        QtMocHelpers::SlotData<void(int)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 5 },
        }}),
        // Slot 'slot_toolButton_shortcut_snapshot_reset'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slot_checkbox_camera_click'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slot_pauseContinue'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slot_setOrUnsetShortcut'
        QtMocHelpers::SlotData<void(bool)>(28, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 5 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<QvkGlobalShortcut, qt_meta_tag_ZN17QvkGlobalShortcutE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject QvkGlobalShortcut::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17QvkGlobalShortcutE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17QvkGlobalShortcutE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17QvkGlobalShortcutE_t>.metaTypes,
    nullptr
} };

void QvkGlobalShortcut::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QvkGlobalShortcut *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->signal_shortcutSystray((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 1: _t->slot_startStop(); break;
        case 2: _t->slot_checkbox_shortcut_start_clicked((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 3: _t->slot_checkbox_shortcut_start_currentIndexChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 4: _t->slot_toolButton_shortcut_start_reset(); break;
        case 5: _t->slot_checkbox_shortcut_pause_clicked((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 6: _t->slot_checkbox_shortcut_pause_currentIndexChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 7: _t->slot_toolButton_shortcut_pause_reset(); break;
        case 8: _t->slot_checkbox_shortcut_magnification_clicked((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 9: _t->slot_checkbox_shortcut_magnification_currentIndexChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 10: _t->slot_toolButton_shortcut_magnification_reset(); break;
        case 11: _t->slot_checkbox_shortcut_camera_clicked((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 12: _t->slot_checkbox_shortcut_camera_currentIndexChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 13: _t->slot_toolButton_shortcut_camera_reset(); break;
        case 14: _t->slot_checkbox_shortcut_showclick_clicked((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 15: _t->slot_checkbox_shortcut_showclick_currentIndexChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 16: _t->slot_toolButton_shortcut_showclick_reset(); break;
        case 17: _t->slot_checkbox_shortcut_halo_clicked((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 18: _t->slot_checkbox_shortcut_halo_currentIndexChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 19: _t->slot_toolButton_shortcut_halo_reset(); break;
        case 20: _t->slot_checkbox_shortcut_snapshot_clicked((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 21: _t->slot_checkbox_shortcut_snapshot_currentIndexChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 22: _t->slot_toolButton_shortcut_snapshot_reset(); break;
        case 23: _t->slot_checkbox_camera_click(); break;
        case 24: _t->slot_pauseContinue(); break;
        case 25: _t->slot_setOrUnsetShortcut((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QvkGlobalShortcut::*)(QString , QString )>(_a, &QvkGlobalShortcut::signal_shortcutSystray, 0))
            return;
    }
}

const QMetaObject *QvkGlobalShortcut::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QvkGlobalShortcut::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17QvkGlobalShortcutE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int QvkGlobalShortcut::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 26)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 26;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 26)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 26;
    }
    return _id;
}

// SIGNAL 0
void QvkGlobalShortcut::signal_shortcutSystray(QString _t1, QString _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}
QT_WARNING_POP
