/********************************************************************************
** Form generated from reading UI file 'camerasettingsdialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CAMERASETTINGSDIALOG_H
#define UI_CAMERASETTINGSDIALOG_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_cameraSettingsDialog
{
public:
    QVBoxLayout *verticalLayout;
    QTabWidget *tabWidget;
    QWidget *tab;
    QVBoxLayout *verticalLayout_2;
    QHBoxLayout *horizontalLayout_4;
    QSpacerItem *horizontalSpacer;
    QComboBox *comboBoxCameraVideoFormat;
    QComboBox *comboBoxCameraResolution;
    QWidget *widgetCameraWindowSize;
    QVBoxLayout *verticalLayout_3;
    QHBoxLayout *horizontalLayout_3;
    QLabel *label;
    QHBoxLayout *horizontalLayout_44;
    QLabel *labelCameraWindowSize;
    QHBoxLayout *horizontalLayout_2;
    QLabel *label_2;
    QHBoxLayout *horizontalLayout_65;
    QSpacerItem *horizontalSpacer_41;
    QToolButton *toolButton_camera_view_rectangle;
    QSpacerItem *horizontalSpacer_35;
    QToolButton *toolButton_camera_view_ellipse;
    QSpacerItem *horizontalSpacer_36;
    QToolButton *toolButton_camera_view_circle;
    QSpacerItem *horizontalSpacer_37;
    QHBoxLayout *horizontalLayout_42;
    QCheckBox *checkBoxCameraWindowFrame;
    QHBoxLayout *horizontalLayout_12;
    QCheckBox *checkBoxCameraMirrorVertical;
    QCheckBox *checkBoxCameraMirrorHorizontal;
    QHBoxLayout *horizontalLayout_14;
    QCheckBox *checkBoxCameraInvert;
    QCheckBox *checkBoxCameraGray;
    QCheckBox *checkBoxCameraMono;
    QPushButton *pushButtonSwitchToFullscreen;
    QSpacerItem *verticalSpacer;
    QHBoxLayout *horizontalLayout;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *cameraSettingsDialog)
    {
        if (cameraSettingsDialog->objectName().isEmpty())
            cameraSettingsDialog->setObjectName("cameraSettingsDialog");
        cameraSettingsDialog->resize(375, 429);
        verticalLayout = new QVBoxLayout(cameraSettingsDialog);
        verticalLayout->setObjectName("verticalLayout");
        tabWidget = new QTabWidget(cameraSettingsDialog);
        tabWidget->setObjectName("tabWidget");
        tabWidget->setIconSize(QSize(48, 48));
        tab = new QWidget();
        tab->setObjectName("tab");
        verticalLayout_2 = new QVBoxLayout(tab);
        verticalLayout_2->setObjectName("verticalLayout_2");
        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_4->addItem(horizontalSpacer);

        comboBoxCameraVideoFormat = new QComboBox(tab);
        comboBoxCameraVideoFormat->setObjectName("comboBoxCameraVideoFormat");

        horizontalLayout_4->addWidget(comboBoxCameraVideoFormat);

        comboBoxCameraResolution = new QComboBox(tab);
        comboBoxCameraResolution->setObjectName("comboBoxCameraResolution");

        horizontalLayout_4->addWidget(comboBoxCameraResolution);


        verticalLayout_2->addLayout(horizontalLayout_4);

        widgetCameraWindowSize = new QWidget(tab);
        widgetCameraWindowSize->setObjectName("widgetCameraWindowSize");
        verticalLayout_3 = new QVBoxLayout(widgetCameraWindowSize);
        verticalLayout_3->setSpacing(0);
        verticalLayout_3->setObjectName("verticalLayout_3");
        verticalLayout_3->setContentsMargins(0, 0, 0, 0);
        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setSpacing(12);
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        label = new QLabel(widgetCameraWindowSize);
        label->setObjectName("label");
        label->setMaximumSize(QSize(34, 34));
        label->setText(QString::fromUtf8(""));
        label->setPixmap(QPixmap(QString::fromUtf8(":/pictures/camera/window-resize.png")));
        label->setScaledContents(true);

        horizontalLayout_3->addWidget(label, 0, Qt::AlignLeft);

        horizontalLayout_44 = new QHBoxLayout();
        horizontalLayout_44->setObjectName("horizontalLayout_44");
        labelCameraWindowSize = new QLabel(widgetCameraWindowSize);
        labelCameraWindowSize->setObjectName("labelCameraWindowSize");
        labelCameraWindowSize->setText(QString::fromUtf8("---x---"));
        labelCameraWindowSize->setAlignment(Qt::AlignCenter);

        horizontalLayout_44->addWidget(labelCameraWindowSize);


        horizontalLayout_3->addLayout(horizontalLayout_44);


        verticalLayout_3->addLayout(horizontalLayout_3);


        verticalLayout_2->addWidget(widgetCameraWindowSize);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setSpacing(12);
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        label_2 = new QLabel(tab);
        label_2->setObjectName("label_2");
        label_2->setMaximumSize(QSize(34, 34));
        label_2->setText(QString::fromUtf8(""));
        label_2->setPixmap(QPixmap(QString::fromUtf8(":/pictures/systray/magnification.png")));
        label_2->setScaledContents(true);

        horizontalLayout_2->addWidget(label_2, 0, Qt::AlignLeft);


        verticalLayout_2->addLayout(horizontalLayout_2);

        horizontalLayout_65 = new QHBoxLayout();
        horizontalLayout_65->setSpacing(0);
        horizontalLayout_65->setObjectName("horizontalLayout_65");
        horizontalLayout_65->setContentsMargins(0, -1, -1, -1);
        horizontalSpacer_41 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_65->addItem(horizontalSpacer_41);

        toolButton_camera_view_rectangle = new QToolButton(tab);
        toolButton_camera_view_rectangle->setObjectName("toolButton_camera_view_rectangle");
        toolButton_camera_view_rectangle->setText(QString::fromUtf8(""));
        QIcon icon;
        icon.addFile(QString::fromUtf8(":/pictures/camera/window-rectangle-off.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        icon.addFile(QString::fromUtf8(":/pictures/camera/window-rectangle-on.png"), QSize(), QIcon::Mode::Normal, QIcon::State::On);
        toolButton_camera_view_rectangle->setIcon(icon);
        toolButton_camera_view_rectangle->setIconSize(QSize(34, 34));
        toolButton_camera_view_rectangle->setCheckable(true);
        toolButton_camera_view_rectangle->setChecked(true);
        toolButton_camera_view_rectangle->setAutoExclusive(true);
        toolButton_camera_view_rectangle->setAutoRaise(true);

        horizontalLayout_65->addWidget(toolButton_camera_view_rectangle);

        horizontalSpacer_35 = new QSpacerItem(40, 20, QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Minimum);

        horizontalLayout_65->addItem(horizontalSpacer_35);

        toolButton_camera_view_ellipse = new QToolButton(tab);
        toolButton_camera_view_ellipse->setObjectName("toolButton_camera_view_ellipse");
        toolButton_camera_view_ellipse->setText(QString::fromUtf8(""));
        QIcon icon1;
        icon1.addFile(QString::fromUtf8(":/pictures/camera/window-ellipse-off.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        icon1.addFile(QString::fromUtf8(":/pictures/camera/window-ellipse-on.png"), QSize(), QIcon::Mode::Normal, QIcon::State::On);
        toolButton_camera_view_ellipse->setIcon(icon1);
        toolButton_camera_view_ellipse->setIconSize(QSize(34, 34));
        toolButton_camera_view_ellipse->setCheckable(true);
        toolButton_camera_view_ellipse->setAutoExclusive(true);
        toolButton_camera_view_ellipse->setAutoRaise(true);

        horizontalLayout_65->addWidget(toolButton_camera_view_ellipse);

        horizontalSpacer_36 = new QSpacerItem(40, 20, QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Minimum);

        horizontalLayout_65->addItem(horizontalSpacer_36);

        toolButton_camera_view_circle = new QToolButton(tab);
        toolButton_camera_view_circle->setObjectName("toolButton_camera_view_circle");
        toolButton_camera_view_circle->setText(QString::fromUtf8(""));
        QIcon icon2;
        icon2.addFile(QString::fromUtf8(":/pictures/camera/window-circle-off.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        icon2.addFile(QString::fromUtf8(":/pictures/camera/window-circle-on.png"), QSize(), QIcon::Mode::Normal, QIcon::State::On);
        toolButton_camera_view_circle->setIcon(icon2);
        toolButton_camera_view_circle->setIconSize(QSize(34, 34));
        toolButton_camera_view_circle->setCheckable(true);
        toolButton_camera_view_circle->setAutoExclusive(true);
        toolButton_camera_view_circle->setAutoRaise(true);

        horizontalLayout_65->addWidget(toolButton_camera_view_circle);

        horizontalSpacer_37 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_65->addItem(horizontalSpacer_37);


        verticalLayout_2->addLayout(horizontalLayout_65);

        horizontalLayout_42 = new QHBoxLayout();
        horizontalLayout_42->setObjectName("horizontalLayout_42");
        checkBoxCameraWindowFrame = new QCheckBox(tab);
        checkBoxCameraWindowFrame->setObjectName("checkBoxCameraWindowFrame");

        horizontalLayout_42->addWidget(checkBoxCameraWindowFrame);


        verticalLayout_2->addLayout(horizontalLayout_42);

        horizontalLayout_12 = new QHBoxLayout();
        horizontalLayout_12->setObjectName("horizontalLayout_12");
        checkBoxCameraMirrorVertical = new QCheckBox(tab);
        checkBoxCameraMirrorVertical->setObjectName("checkBoxCameraMirrorVertical");

        horizontalLayout_12->addWidget(checkBoxCameraMirrorVertical);

        checkBoxCameraMirrorHorizontal = new QCheckBox(tab);
        checkBoxCameraMirrorHorizontal->setObjectName("checkBoxCameraMirrorHorizontal");

        horizontalLayout_12->addWidget(checkBoxCameraMirrorHorizontal);


        verticalLayout_2->addLayout(horizontalLayout_12);

        horizontalLayout_14 = new QHBoxLayout();
        horizontalLayout_14->setObjectName("horizontalLayout_14");
        checkBoxCameraInvert = new QCheckBox(tab);
        checkBoxCameraInvert->setObjectName("checkBoxCameraInvert");

        horizontalLayout_14->addWidget(checkBoxCameraInvert);

        checkBoxCameraGray = new QCheckBox(tab);
        checkBoxCameraGray->setObjectName("checkBoxCameraGray");

        horizontalLayout_14->addWidget(checkBoxCameraGray);

        checkBoxCameraMono = new QCheckBox(tab);
        checkBoxCameraMono->setObjectName("checkBoxCameraMono");

        horizontalLayout_14->addWidget(checkBoxCameraMono);


        verticalLayout_2->addLayout(horizontalLayout_14);

        pushButtonSwitchToFullscreen = new QPushButton(tab);
        pushButtonSwitchToFullscreen->setObjectName("pushButtonSwitchToFullscreen");
        pushButtonSwitchToFullscreen->setText(QString::fromUtf8("Switch to Fullscreen"));

        verticalLayout_2->addWidget(pushButtonSwitchToFullscreen);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_2->addItem(verticalSpacer);

        QIcon icon3;
        icon3.addFile(QString::fromUtf8(":/pictures/camera/camera.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        tabWidget->addTab(tab, icon3, QString());
        tabWidget->setTabText(tabWidget->indexOf(tab), QString::fromUtf8(""));

        verticalLayout->addWidget(tabWidget);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        buttonBox = new QDialogButtonBox(cameraSettingsDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::Ok);

        horizontalLayout->addWidget(buttonBox);


        verticalLayout->addLayout(horizontalLayout);


        retranslateUi(cameraSettingsDialog);

        tabWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(cameraSettingsDialog);
    } // setupUi

    void retranslateUi(QDialog *cameraSettingsDialog)
    {
        cameraSettingsDialog->setWindowTitle(QCoreApplication::translate("cameraSettingsDialog", "Dialog", nullptr));
        checkBoxCameraWindowFrame->setText(QCoreApplication::translate("cameraSettingsDialog", "Remove window frame", nullptr));
        checkBoxCameraMirrorVertical->setText(QCoreApplication::translate("cameraSettingsDialog", "Flip vertical", nullptr));
        checkBoxCameraMirrorHorizontal->setText(QCoreApplication::translate("cameraSettingsDialog", "Flip horizontal", nullptr));
        checkBoxCameraInvert->setText(QCoreApplication::translate("cameraSettingsDialog", "Invert", nullptr));
        checkBoxCameraGray->setText(QCoreApplication::translate("cameraSettingsDialog", "Gray", nullptr));
        checkBoxCameraMono->setText(QCoreApplication::translate("cameraSettingsDialog", "Black-and-white", nullptr));
    } // retranslateUi

};

namespace Ui {
    class cameraSettingsDialog: public Ui_cameraSettingsDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_CAMERASETTINGSDIALOG_H
