#ifndef QVKVIRTUAL_H 
#define QVKVIRTUAL_H

#include <QObject>

class QvkVirtual: public QObject
{
    Q_OBJECT
public:
    QvkVirtual();
    QString isVirtualMaschine();

public slots:


private:


private slots:

    
signals:

};

#endif // QVKVIRTUAL_H
