/********************************************************************************
** Form generated from reading UI file 'formMainWindow_wl.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_FORMMAINWINDOW_WL_H
#define UI_FORMMAINWINDOW_WL_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QMainWindow>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QScrollArea>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QTextBrowser>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_formMainWindow_wl
{
public:
    QWidget *centralwidget;
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout_13;
    QVBoxLayout *verticalLayout_5;
    QToolButton *toolButtonScreencast;
    QToolButton *toolButtonCamera;
    QToolButton *toolButtonSnapshot;
    QToolButton *toolButtonConvert;
    QToolButton *toolButtonLog;
    QSpacerItem *verticalSpacer;
    QTabWidget *tabWidgetSideBar;
    QWidget *tab_sidebar_screeancast;
    QVBoxLayout *verticalLayout_2;
    QTabWidget *tabWidgetScreencast;
    QWidget *tabScreen;
    QHBoxLayout *horizontalLayout_15;
    QVBoxLayout *verticalLayout_7;
    QGridLayout *gridLayout_2;
    QRadioButton *radioButtonScreencastWindow;
    QHBoxLayout *horizontalLayout_34;
    QSpacerItem *horizontalSpacer_20;
    QRadioButton *radioButtonScreencastArea;
    QToolButton *toolButtonScreencastAreaReset;
    QRadioButton *radioButtonScreencastFullscreen;
    QSpacerItem *horizontalSpacer_2;
    QFrame *line_2;
    QGridLayout *gridLayout_6;
    QVBoxLayout *verticalLayout_20;
    QToolButton *help_screencast_audio;
    QSpacerItem *verticalSpacer_3;
    QFrame *frame_audio;
    QVBoxLayout *verticalLayout_14;
    QScrollArea *scrollAreaAudioDevice;
    QWidget *scrollAreaWidgetContentsAudioDevices;
    QVBoxLayout *verticalLayoutAudioDevices;
    QFrame *frame_3;
    QHBoxLayout *horizontalLayout_18;
    QLabel *labelAudioCodec;
    QComboBox *comboBoxAudioCodec;
    QSpacerItem *horizontalSpacer_14;
    QCheckBox *checkBoxSeparatedAudioTracks;
    QToolButton *toolButtonSeparatedAudioTracksReset;
    QToolButton *help_screencast_audiocodec;
    QFrame *line_6;
    QFrame *frame_video;
    QVBoxLayout *verticalLayout_8;
    QGridLayout *gridLayoutFormatCodecs;
    QToolButton *help_screencast_nomousecursor;
    QHBoxLayout *horizontalLayout_23;
    QLabel *label_16;
    QHBoxLayout *horizontalLayout_openh264;
    QLabel *label_36;
    QToolButton *toolButtonOpenh264Reset;
    QToolButton *help_screencast_format;
    QLabel *labelVideoCodec;
    QLabel *labelFormat;
    QFrame *frameFrames;
    QHBoxLayout *horizontalLayout_33;
    QToolButton *toolButtonFramesReset;
    QToolButton *help_screencast_frames;
    QFrame *frame;
    QHBoxLayout *horizontalLayout_3;
    QCheckBox *checkBoxMouseCursorOnOff;
    QLabel *labelFrames;
    QSpacerItem *horizontalSpacer_5;
    QVBoxLayout *verticalLayout_30;
    QLabel *label_17;
    QVBoxLayout *verticalLayout_29;
    QToolButton *help_screencast_videocodec;
    QSpacerItem *horizontalSpacer;
    QFrame *line_3;
    QHBoxLayout *horizontalLayout_10;
    QLabel *labelScreencastCountdownText;
    QSpacerItem *horizontalSpacer_3;
    QToolButton *help_screencast_countdown;
    QFrame *line_5;
    QGridLayout *gridLayout_8;
    QSpacerItem *verticalSpacer_22;
    QGridLayout *gridLayout_9;
    QLabel *label_30;
    QLabel *label_29;
    QLabel *labelInfoAudiocodec;
    QLabel *label_19;
    QLabel *label_27;
    QLabel *labelInfoFrames;
    QLabel *label_31;
    QLabel *label_33;
    QLabel *labelInfoFormat;
    QLabel *label_20;
    QLabel *labelVideoSize;
    QLabel *label_28;
    QFrame *line_4;
    QLabel *labelInfoRecordTime;
    QLabel *label_32;
    QLabel *labelFreeSize;
    QLabel *labelInfoVideocodec;
    QSpacerItem *verticalSpacer_5;
    QLabel *label_18;
    QLabel *label_Upate_tab_2;
    QWidget *tabMisc;
    QHBoxLayout *horizontalLayout_4;
    QGridLayout *gridLayout_10;
    QHBoxLayout *horizontalLayout_25;
    QFrame *frameVideoPath;
    QHBoxLayout *horizontalLayout_20;
    QLabel *LabelVideoPath;
    QLineEdit *lineEditVideoPath;
    QToolButton *toolButtonVideoPath;
    QToolButton *toolButtonVideoPathReset;
    QSpacerItem *verticalSpacer_2;
    QWidget *widgetLanguageAndHelp;
    QHBoxLayout *horizontalLayout_32;
    QLabel *label_66;
    QComboBox *comboBoxLanguage;
    QSpacerItem *horizontalSpacer_52;
    QLabel *label_35;
    QComboBox *comboBoxOnlineHelp;
    QSpacerItem *horizontalSpacer_29;
    QCheckBox *checkBoxResetAtNextStart;
    QHBoxLayout *horizontalLayout_7;
    QCheckBox *checkBoxShowInSystray;
    QSpacerItem *horizontalSpacer_4;
    QHBoxLayout *horizontalLayout_9;
    QLabel *label_34;
    QSpacerItem *horizontalSpacer_44;
    QHBoxLayout *horizontalLayout_26;
    QCheckBox *checkBoxMinimizedWhenRecordingStarts;
    QWidget *tabAvailable;
    QHBoxLayout *horizontalLayout_5;
    QVBoxLayout *verticalLayout_19;
    QGridLayout *gridLayout_7;
    QLabel *label_24;
    QLabel *label_25;
    QLabel *label_26;
    QScrollArea *scrollAreaAvailable;
    QWidget *scrollAreaWidgetContentsAvailable;
    QGridLayout *gridLayoutAvailable;
    QVBoxLayout *verticalLayout_17;
    QVBoxLayout *verticalLayout_18;
    QLabel *label_21;
    QHBoxLayout *horizontalLayout_8;
    QLabel *labelAvalible;
    QLabel *label_22;
    QSpacerItem *horizontalSpacer_7;
    QHBoxLayout *horizontalLayout_11;
    QLabel *labelNotAvailable;
    QLabel *label_23;
    QSpacerItem *horizontalSpacer_25;
    QSpacerItem *verticalSpacer_9;
    QVBoxLayout *verticalLayout_16;
    QToolButton *help_screencast_avalaible;
    QSpacerItem *verticalSpacer_8;
    QWidget *tab;
    QVBoxLayout *verticalLayout_42;
    QSpacerItem *verticalSpacer_30;
    QSpacerItem *verticalSpacer_31;
    QGridLayout *gridLayout_16;
    QLabel *labelAutorPicture;
    QVBoxLayout *verticalLayout_37;
    QLabel *labelSourcecodeUrl;
    QLabel *labelWebSiteUrl;
    QVBoxLayout *verticalLayout_38;
    QLabel *labelLanguageUrl;
    QLabel *labelDonateUrl;
    QSpacerItem *verticalSpacer_28;
    QFrame *line_14;
    QSpacerItem *verticalSpacer_26;
    QHBoxLayout *horizontalLayout_40;
    QSpacerItem *horizontalSpacer_13;
    QPushButton *pushButtonLicense;
    QSpacerItem *horizontalSpacer_15;
    QSpacerItem *verticalSpacer_4;
    QSpacerItem *verticalSpacer_29;
    QHBoxLayout *horizontalLayout_63;
    QSpacerItem *horizontalSpacer_56;
    QPushButton *pushButtonImages;
    QSpacerItem *horizontalSpacer_33;
    QLabel *label_save_image_path;
    QFrame *line_cisco;
    QFrame *frame_cisco;
    QVBoxLayout *verticalLayout_39;
    QGridLayout *gridLayout_17;
    QFrame *frame_2;
    QVBoxLayout *verticalLayout_41;
    QLabel *label_cisco_hint;
    QPushButton *pushButtonCiscoLicense;
    QLabel *label_openh264_homepage;
    QHBoxLayout *horizontalLayout_39;
    QSpacerItem *horizontalSpacer_22;
    QRadioButton *radioButton_cisco_on;
    QRadioButton *radioButton_cisco_off;
    QSpacerItem *horizontalSpacer_24;
    QHBoxLayout *horizontalLayout_2;
    QPushButton *pushButtonStart;
    QPushButton *pushButtonStop;
    QPushButton *pushButtonPause;
    QPushButton *pushButtonContinue;
    QPushButton *pushButtonOpenfolder;
    QSpacerItem *horizontalSpacer_10;
    QPushButton *pushButtonSnapshot_2;
    QPushButton *pushButtonSnapshotOpenFolder_2;
    QWidget *tabSidebarCamera;
    QVBoxLayout *verticalLayout_10;
    QTabWidget *tabWidgetCamera;
    QWidget *tabCamera;
    QVBoxLayout *verticalLayout_11;
    QLabel *label_4;
    QFrame *line_9;
    QGridLayout *gridLayout_3;
    QVBoxLayout *layoutAllCameras;
    QGridLayout *gridLayout_4;
    QToolButton *help_camera_camera;
    QLabel *label_camera_window_zoom;
    QHBoxLayout *horizontalLayout_16;
    QCheckBox *checkBoxCameraInvert;
    QSpacerItem *horizontalSpacer_39;
    QCheckBox *checkBoxCameraGray;
    QSpacerItem *horizontalSpacer_40;
    QCheckBox *checkBoxCameraMono;
    QSpacerItem *horizontalSpacer_34;
    QHBoxLayout *horizontalLayout_zoom;
    QHBoxLayout *horizontalLayout_64;
    QCheckBox *checkBoxCameraOnOff;
    QComboBox *comboBoxCamera;
    QComboBox *comboBoxCameraResolution;
    QHBoxLayout *horizontalLayout_66;
    QHBoxLayout *horizontalLayout_45;
    QLabel *labelCameraWindowSize;
    QLabel *label_camera_window_resize;
    QHBoxLayout *horizontalLayout_17;
    QCheckBox *checkBoxCameraMirrorVertical;
    QSpacerItem *horizontalSpacer_38;
    QCheckBox *checkBoxCameraMirrorHorizontal;
    QSpacerItem *horizontalSpacer_9;
    QHBoxLayout *horizontalLayout_65;
    QSpacerItem *horizontalSpacer_41;
    QToolButton *toolButton_camera_view_rectangle;
    QSpacerItem *horizontalSpacer_35;
    QToolButton *toolButton_camera_view_ellipse;
    QSpacerItem *horizontalSpacer_36;
    QToolButton *toolButton_camera_view_circle;
    QSpacerItem *horizontalSpacer_37;
    QHBoxLayout *horizontalLayout_42;
    QCheckBox *checkBoxCameraWindowFrame;
    QSpacerItem *verticalSpacer_6;
    QWidget *tab_sidebar_snapshot;
    QVBoxLayout *verticalLayout_12;
    QTabWidget *tabWidgetSnapshot;
    QWidget *tab_2;
    QVBoxLayout *verticalLayout_13;
    QLabel *label_2;
    QFrame *line;
    QGridLayout *gridLayout;
    QHBoxLayout *horizontalLayout_44;
    QComboBox *comboBoxSnapshotImageFormats;
    QToolButton *toolButtonSnapshotFormatsReset;
    QSpacerItem *horizontalSpacer_26;
    QLabel *label_57;
    QCheckBox *checkBox_snapshot_interactive;
    QHBoxLayout *horizontalLayout_59;
    QLabel *label_60;
    QToolButton *toolButtonSnapshotSecondsWaitBeforeRecordingReset;
    QSpacerItem *horizontalSpacer_12;
    QHBoxLayout *horizontalLayout_24;
    QCheckBox *checkBoxSnapshotHideBeforeRecording;
    QToolButton *toolButtonSnapshotHideBeforeRecordingReset;
    QSpacerItem *horizontalSpacer_11;
    QCheckBox *checkBoxSnapshotShowBallonInSystray;
    QSpacerItem *verticalSpacer_7;
    QHBoxLayout *horizontalLayout_14;
    QSpacerItem *horizontalSpacer_8;
    QPushButton *pushButtonSnapshotOpenFolder;
    QPushButton *pushButtonSnapshot;
    QWidget *tab_3;
    QVBoxLayout *verticalLayout_21;
    QTabWidget *tabWidgetConvert;
    QWidget *tab_5;
    QVBoxLayout *verticalLayout_23;
    QLabel *label_14;
    QGridLayout *gridLayout_5;
    QFrame *line_11;
    QVBoxLayout *verticalLayout_25;
    QHBoxLayout *horizontalLayout_21;
    QLineEdit *lineEdit_convert_mkv_to_gif;
    QToolButton *toolButton_convert_dialog_mkv_to_gif;
    QPushButton *pushButton_convert_mkv_to_gif;
    QWidget *widget_convert_mkv_to_gif;
    QHBoxLayout *horizontalLayout_22;
    QLabel *label_convert_mkv_to_gif;
    QLabel *label_15;
    QVBoxLayout *verticalLayout_24;
    QHBoxLayout *horizontalLayout;
    QLineEdit *lineEdit_convert_mkv_to_mp4;
    QToolButton *toolButton_convert_dialog_mkv_to_mp4;
    QPushButton *pushButton_convert_mkv_to_mp4;
    QWidget *widget_convert_mkv_to_mp4;
    QHBoxLayout *horizontalLayout_19;
    QLabel *label_convert_mkv_to_mp4;
    QFrame *line_10;
    QVBoxLayout *verticalLayout_27;
    QHBoxLayout *horizontalLayout_36;
    QLineEdit *lineEdit_convert_mkv_to_webm;
    QToolButton *toolButton_convert_dialog_mkv_to_webm;
    QPushButton *pushButton_convert_mkv_to_webm;
    QWidget *widget_convert_mkv_to_webm;
    QHBoxLayout *horizontalLayout_38;
    QLabel *label_convert_mkv_to_webm;
    QVBoxLayout *verticalLayout_26;
    QHBoxLayout *horizontalLayout_30;
    QLineEdit *lineEdit_convert_mkv_repair;
    QToolButton *toolButton_convert_dialog_mkv_repair;
    QPushButton *pushButton_convert_mkv_repair;
    QWidget *widget_convert_mkv_repair;
    QHBoxLayout *horizontalLayout_31;
    QLabel *label_convert_mkv_repair;
    QSpacerItem *verticalSpacer_12;
    QLabel *label_12;
    QLabel *label_13;
    QLabel *label_9;
    QLabel *label_8;
    QLabel *label_7;
    QLabel *label_6;
    QLabel *label_5;
    QLabel *label_3;
    QLabel *label_11;
    QLabel *label_10;
    QSpacerItem *verticalSpacer_10;
    QWidget *tabSidebarLog;
    QVBoxLayout *verticalLayout_4;
    QTabWidget *tabWidgetLog;
    QWidget *tabLog;
    QVBoxLayout *verticalLayout_9;
    QLabel *label;
    QFrame *line_8;
    QTextBrowser *textBrowser;
    QHBoxLayout *horizontalLayout_12;
    QSpacerItem *horizontalSpacer_6;
    QPushButton *pushButton_log_openfolder;
    QPushButton *pushButton_log_refresh;
    QButtonGroup *buttonGroup;
    QButtonGroup *buttonGroup_2;

    void setupUi(QMainWindow *formMainWindow_wl)
    {
        if (formMainWindow_wl->objectName().isEmpty())
            formMainWindow_wl->setObjectName("formMainWindow_wl");
        formMainWindow_wl->resize(820, 498);
        formMainWindow_wl->setWindowTitle(QString::fromUtf8("vokoscreenNG"));
        centralwidget = new QWidget(formMainWindow_wl);
        centralwidget->setObjectName("centralwidget");
        verticalLayout = new QVBoxLayout(centralwidget);
        verticalLayout->setSpacing(0);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        horizontalLayout_13 = new QHBoxLayout();
        horizontalLayout_13->setSpacing(0);
        horizontalLayout_13->setObjectName("horizontalLayout_13");
        verticalLayout_5 = new QVBoxLayout();
        verticalLayout_5->setSpacing(0);
        verticalLayout_5->setObjectName("verticalLayout_5");
        toolButtonScreencast = new QToolButton(centralwidget);
        buttonGroup_2 = new QButtonGroup(formMainWindow_wl);
        buttonGroup_2->setObjectName("buttonGroup_2");
        buttonGroup_2->addButton(toolButtonScreencast);
        toolButtonScreencast->setObjectName("toolButtonScreencast");
        toolButtonScreencast->setMinimumSize(QSize(110, 56));
        toolButtonScreencast->setText(QString::fromUtf8(""));
        QIcon icon;
        icon.addFile(QString::fromUtf8(":/pictures/screencast/monitor.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        toolButtonScreencast->setIcon(icon);
        toolButtonScreencast->setIconSize(QSize(48, 48));
        toolButtonScreencast->setCheckable(true);
        toolButtonScreencast->setAutoExclusive(true);
        toolButtonScreencast->setAutoRaise(true);

        verticalLayout_5->addWidget(toolButtonScreencast);

        toolButtonCamera = new QToolButton(centralwidget);
        buttonGroup_2->addButton(toolButtonCamera);
        toolButtonCamera->setObjectName("toolButtonCamera");
        toolButtonCamera->setMinimumSize(QSize(110, 56));
        toolButtonCamera->setText(QString::fromUtf8(""));
        QIcon icon1;
        icon1.addFile(QString::fromUtf8(":/pictures/camera/camera.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        toolButtonCamera->setIcon(icon1);
        toolButtonCamera->setIconSize(QSize(48, 48));
        toolButtonCamera->setCheckable(true);
        toolButtonCamera->setAutoExclusive(true);
        toolButtonCamera->setAutoRaise(true);

        verticalLayout_5->addWidget(toolButtonCamera);

        toolButtonSnapshot = new QToolButton(centralwidget);
        buttonGroup_2->addButton(toolButtonSnapshot);
        toolButtonSnapshot->setObjectName("toolButtonSnapshot");
        toolButtonSnapshot->setMinimumSize(QSize(110, 56));
        toolButtonSnapshot->setText(QString::fromUtf8(""));
        QIcon icon2;
        icon2.addFile(QString::fromUtf8(":/pictures/snapshot/snapshot.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        toolButtonSnapshot->setIcon(icon2);
        toolButtonSnapshot->setIconSize(QSize(48, 48));
        toolButtonSnapshot->setCheckable(true);
        toolButtonSnapshot->setAutoExclusive(true);
        toolButtonSnapshot->setAutoRaise(true);

        verticalLayout_5->addWidget(toolButtonSnapshot);

        toolButtonConvert = new QToolButton(centralwidget);
        buttonGroup_2->addButton(toolButtonConvert);
        toolButtonConvert->setObjectName("toolButtonConvert");
        toolButtonConvert->setMinimumSize(QSize(110, 56));
        toolButtonConvert->setText(QString::fromUtf8(""));
        QIcon icon3;
        icon3.addFile(QString::fromUtf8(":/pictures/screencast/convert.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        toolButtonConvert->setIcon(icon3);
        toolButtonConvert->setIconSize(QSize(48, 48));
        toolButtonConvert->setCheckable(true);
        toolButtonConvert->setAutoExclusive(true);
        toolButtonConvert->setAutoRaise(true);

        verticalLayout_5->addWidget(toolButtonConvert);

        toolButtonLog = new QToolButton(centralwidget);
        buttonGroup_2->addButton(toolButtonLog);
        toolButtonLog->setObjectName("toolButtonLog");
        toolButtonLog->setMinimumSize(QSize(110, 56));
        toolButtonLog->setText(QString::fromUtf8(""));
        QIcon icon4;
        icon4.addFile(QString::fromUtf8(":/pictures/log/log.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        toolButtonLog->setIcon(icon4);
        toolButtonLog->setIconSize(QSize(48, 48));
        toolButtonLog->setCheckable(true);
        toolButtonLog->setAutoExclusive(true);
        toolButtonLog->setAutoRaise(true);

        verticalLayout_5->addWidget(toolButtonLog);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_5->addItem(verticalSpacer);


        horizontalLayout_13->addLayout(verticalLayout_5);

        tabWidgetSideBar = new QTabWidget(centralwidget);
        tabWidgetSideBar->setObjectName("tabWidgetSideBar");
        tabWidgetSideBar->setTabPosition(QTabWidget::West);
        tab_sidebar_screeancast = new QWidget();
        tab_sidebar_screeancast->setObjectName("tab_sidebar_screeancast");
        verticalLayout_2 = new QVBoxLayout(tab_sidebar_screeancast);
        verticalLayout_2->setSpacing(0);
        verticalLayout_2->setObjectName("verticalLayout_2");
        verticalLayout_2->setContentsMargins(0, 0, 0, 0);
        tabWidgetScreencast = new QTabWidget(tab_sidebar_screeancast);
        tabWidgetScreencast->setObjectName("tabWidgetScreencast");
        tabWidgetScreencast->setIconSize(QSize(48, 48));
        tabScreen = new QWidget();
        tabScreen->setObjectName("tabScreen");
        horizontalLayout_15 = new QHBoxLayout(tabScreen);
        horizontalLayout_15->setObjectName("horizontalLayout_15");
        verticalLayout_7 = new QVBoxLayout();
        verticalLayout_7->setObjectName("verticalLayout_7");
        verticalLayout_7->setContentsMargins(-1, -1, -1, 0);
        gridLayout_2 = new QGridLayout();
        gridLayout_2->setObjectName("gridLayout_2");
        gridLayout_2->setContentsMargins(-1, -1, -1, 0);
        radioButtonScreencastWindow = new QRadioButton(tabScreen);
        buttonGroup = new QButtonGroup(formMainWindow_wl);
        buttonGroup->setObjectName("buttonGroup");
        buttonGroup->addButton(radioButtonScreencastWindow);
        radioButtonScreencastWindow->setObjectName("radioButtonScreencastWindow");

        gridLayout_2->addWidget(radioButtonScreencastWindow, 1, 0, 1, 1);

        horizontalLayout_34 = new QHBoxLayout();
        horizontalLayout_34->setObjectName("horizontalLayout_34");
        horizontalLayout_34->setContentsMargins(-1, -1, 0, -1);
        horizontalSpacer_20 = new QSpacerItem(40, 20, QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Minimum);

        horizontalLayout_34->addItem(horizontalSpacer_20);

        radioButtonScreencastArea = new QRadioButton(tabScreen);
        buttonGroup->addButton(radioButtonScreencastArea);
        radioButtonScreencastArea->setObjectName("radioButtonScreencastArea");

        horizontalLayout_34->addWidget(radioButtonScreencastArea);

        toolButtonScreencastAreaReset = new QToolButton(tabScreen);
        toolButtonScreencastAreaReset->setObjectName("toolButtonScreencastAreaReset");
        toolButtonScreencastAreaReset->setText(QString::fromUtf8(""));
        QIcon icon5;
        icon5.addFile(QString::fromUtf8(":/pictures/screencast/undo.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        toolButtonScreencastAreaReset->setIcon(icon5);

        horizontalLayout_34->addWidget(toolButtonScreencastAreaReset);


        gridLayout_2->addLayout(horizontalLayout_34, 0, 1, 2, 1);

        radioButtonScreencastFullscreen = new QRadioButton(tabScreen);
        buttonGroup->addButton(radioButtonScreencastFullscreen);
        radioButtonScreencastFullscreen->setObjectName("radioButtonScreencastFullscreen");
        radioButtonScreencastFullscreen->setChecked(false);

        gridLayout_2->addWidget(radioButtonScreencastFullscreen, 0, 0, 1, 1);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_2->addItem(horizontalSpacer_2, 0, 2, 1, 1);


        verticalLayout_7->addLayout(gridLayout_2);

        line_2 = new QFrame(tabScreen);
        line_2->setObjectName("line_2");
        line_2->setStyleSheet(QString::fromUtf8("color: rgb(200, 200, 200);"));
        line_2->setFrameShadow(QFrame::Plain);
        line_2->setFrameShape(QFrame::Shape::HLine);

        verticalLayout_7->addWidget(line_2);

        gridLayout_6 = new QGridLayout();
        gridLayout_6->setObjectName("gridLayout_6");
        verticalLayout_20 = new QVBoxLayout();
        verticalLayout_20->setObjectName("verticalLayout_20");
        help_screencast_audio = new QToolButton(tabScreen);
        help_screencast_audio->setObjectName("help_screencast_audio");
        help_screencast_audio->setText(QString::fromUtf8("Help"));

        verticalLayout_20->addWidget(help_screencast_audio, 0, Qt::AlignTop);

        verticalSpacer_3 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_20->addItem(verticalSpacer_3);


        gridLayout_6->addLayout(verticalLayout_20, 0, 1, 1, 1);

        frame_audio = new QFrame(tabScreen);
        frame_audio->setObjectName("frame_audio");
        frame_audio->setFrameShape(QFrame::NoFrame);
        frame_audio->setFrameShadow(QFrame::Raised);
        verticalLayout_14 = new QVBoxLayout(frame_audio);
        verticalLayout_14->setObjectName("verticalLayout_14");
        verticalLayout_14->setContentsMargins(0, 0, -1, 0);
        scrollAreaAudioDevice = new QScrollArea(frame_audio);
        scrollAreaAudioDevice->setObjectName("scrollAreaAudioDevice");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(scrollAreaAudioDevice->sizePolicy().hasHeightForWidth());
        scrollAreaAudioDevice->setSizePolicy(sizePolicy);
#if QT_CONFIG(accessibility)
        scrollAreaAudioDevice->setAccessibleName(QString::fromUtf8(""));
#endif // QT_CONFIG(accessibility)
        scrollAreaAudioDevice->setFrameShape(QFrame::NoFrame);
        scrollAreaAudioDevice->setWidgetResizable(true);
        scrollAreaAudioDevice->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignTop);
        scrollAreaWidgetContentsAudioDevices = new QWidget();
        scrollAreaWidgetContentsAudioDevices->setObjectName("scrollAreaWidgetContentsAudioDevices");
        scrollAreaWidgetContentsAudioDevices->setGeometry(QRect(0, 0, 401, 116));
#if QT_CONFIG(accessibility)
        scrollAreaWidgetContentsAudioDevices->setAccessibleName(QString::fromUtf8(""));
#endif // QT_CONFIG(accessibility)
        verticalLayoutAudioDevices = new QVBoxLayout(scrollAreaWidgetContentsAudioDevices);
        verticalLayoutAudioDevices->setSpacing(3);
        verticalLayoutAudioDevices->setObjectName("verticalLayoutAudioDevices");
        verticalLayoutAudioDevices->setContentsMargins(0, 6, 6, 20);
        scrollAreaAudioDevice->setWidget(scrollAreaWidgetContentsAudioDevices);

        verticalLayout_14->addWidget(scrollAreaAudioDevice);


        gridLayout_6->addWidget(frame_audio, 0, 0, 2, 1);

        frame_3 = new QFrame(tabScreen);
        frame_3->setObjectName("frame_3");
        frame_3->setFrameShape(QFrame::NoFrame);
        frame_3->setFrameShadow(QFrame::Raised);
        horizontalLayout_18 = new QHBoxLayout(frame_3);
        horizontalLayout_18->setSpacing(6);
        horizontalLayout_18->setObjectName("horizontalLayout_18");
        horizontalLayout_18->setContentsMargins(0, 0, -1, 0);
        labelAudioCodec = new QLabel(frame_3);
        labelAudioCodec->setObjectName("labelAudioCodec");

        horizontalLayout_18->addWidget(labelAudioCodec);

        comboBoxAudioCodec = new QComboBox(frame_3);
        comboBoxAudioCodec->setObjectName("comboBoxAudioCodec");
        comboBoxAudioCodec->setSizeAdjustPolicy(QComboBox::AdjustToContents);

        horizontalLayout_18->addWidget(comboBoxAudioCodec);

        horizontalSpacer_14 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_18->addItem(horizontalSpacer_14);

        checkBoxSeparatedAudioTracks = new QCheckBox(frame_3);
        checkBoxSeparatedAudioTracks->setObjectName("checkBoxSeparatedAudioTracks");
        checkBoxSeparatedAudioTracks->setText(QString::fromUtf8("Separated audio tracks"));

        horizontalLayout_18->addWidget(checkBoxSeparatedAudioTracks);

        toolButtonSeparatedAudioTracksReset = new QToolButton(frame_3);
        toolButtonSeparatedAudioTracksReset->setObjectName("toolButtonSeparatedAudioTracksReset");
        toolButtonSeparatedAudioTracksReset->setText(QString::fromUtf8(""));
        toolButtonSeparatedAudioTracksReset->setIcon(icon5);

        horizontalLayout_18->addWidget(toolButtonSeparatedAudioTracksReset);


        gridLayout_6->addWidget(frame_3, 2, 0, 1, 1);

        help_screencast_audiocodec = new QToolButton(tabScreen);
        help_screencast_audiocodec->setObjectName("help_screencast_audiocodec");
        help_screencast_audiocodec->setText(QString::fromUtf8("Help"));

        gridLayout_6->addWidget(help_screencast_audiocodec, 2, 1, 1, 1);


        verticalLayout_7->addLayout(gridLayout_6);

        line_6 = new QFrame(tabScreen);
        line_6->setObjectName("line_6");
        line_6->setStyleSheet(QString::fromUtf8("color: rgb(200, 200, 200);"));
        line_6->setFrameShadow(QFrame::Plain);
        line_6->setFrameShape(QFrame::Shape::HLine);

        verticalLayout_7->addWidget(line_6);

        frame_video = new QFrame(tabScreen);
        frame_video->setObjectName("frame_video");
        frame_video->setFrameShape(QFrame::NoFrame);
        verticalLayout_8 = new QVBoxLayout(frame_video);
        verticalLayout_8->setObjectName("verticalLayout_8");
        verticalLayout_8->setContentsMargins(0, 0, 0, 0);
        gridLayoutFormatCodecs = new QGridLayout();
        gridLayoutFormatCodecs->setObjectName("gridLayoutFormatCodecs");
        help_screencast_nomousecursor = new QToolButton(frame_video);
        help_screencast_nomousecursor->setObjectName("help_screencast_nomousecursor");
        help_screencast_nomousecursor->setText(QString::fromUtf8("Help"));

        gridLayoutFormatCodecs->addWidget(help_screencast_nomousecursor, 1, 3, 1, 1, Qt::AlignRight);

        horizontalLayout_23 = new QHBoxLayout();
        horizontalLayout_23->setObjectName("horizontalLayout_23");
        horizontalLayout_23->setContentsMargins(6, -1, -1, -1);
        label_16 = new QLabel(frame_video);
        label_16->setObjectName("label_16");
        label_16->setText(QString::fromUtf8("H.264"));

        horizontalLayout_23->addWidget(label_16);

        horizontalLayout_openh264 = new QHBoxLayout();
        horizontalLayout_openh264->setSpacing(6);
        horizontalLayout_openh264->setObjectName("horizontalLayout_openh264");
        label_36 = new QLabel(frame_video);
        label_36->setObjectName("label_36");
        label_36->setMinimumSize(QSize(0, 0));
        label_36->setMaximumSize(QSize(28, 28));
        label_36->setText(QString::fromUtf8(""));
        label_36->setPixmap(QPixmap(QString::fromUtf8(":/pictures/screencast/compress.png")));
        label_36->setScaledContents(true);

        horizontalLayout_openh264->addWidget(label_36, 0, Qt::AlignVCenter);

        toolButtonOpenh264Reset = new QToolButton(frame_video);
        toolButtonOpenh264Reset->setObjectName("toolButtonOpenh264Reset");
        toolButtonOpenh264Reset->setText(QString::fromUtf8(""));
        toolButtonOpenh264Reset->setIcon(icon5);

        horizontalLayout_openh264->addWidget(toolButtonOpenh264Reset);


        horizontalLayout_23->addLayout(horizontalLayout_openh264);


        gridLayoutFormatCodecs->addLayout(horizontalLayout_23, 3, 1, 1, 1);

        help_screencast_format = new QToolButton(frame_video);
        help_screencast_format->setObjectName("help_screencast_format");
        help_screencast_format->setText(QString::fromUtf8("Help"));

        gridLayoutFormatCodecs->addWidget(help_screencast_format, 2, 3, 1, 1, Qt::AlignRight);

        labelVideoCodec = new QLabel(frame_video);
        labelVideoCodec->setObjectName("labelVideoCodec");

        gridLayoutFormatCodecs->addWidget(labelVideoCodec, 3, 0, 1, 1);

        labelFormat = new QLabel(frame_video);
        labelFormat->setObjectName("labelFormat");
        labelFormat->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayoutFormatCodecs->addWidget(labelFormat, 2, 0, 1, 1, Qt::AlignLeft);

        frameFrames = new QFrame(frame_video);
        frameFrames->setObjectName("frameFrames");
        frameFrames->setFrameShape(QFrame::NoFrame);
        frameFrames->setFrameShadow(QFrame::Raised);
        horizontalLayout_33 = new QHBoxLayout(frameFrames);
        horizontalLayout_33->setSpacing(6);
        horizontalLayout_33->setObjectName("horizontalLayout_33");
        horizontalLayout_33->setContentsMargins(6, 0, 0, 0);
        toolButtonFramesReset = new QToolButton(frameFrames);
        toolButtonFramesReset->setObjectName("toolButtonFramesReset");
        toolButtonFramesReset->setText(QString::fromUtf8(""));
        toolButtonFramesReset->setIcon(icon5);

        horizontalLayout_33->addWidget(toolButtonFramesReset);

        help_screencast_frames = new QToolButton(frameFrames);
        help_screencast_frames->setObjectName("help_screencast_frames");
        help_screencast_frames->setText(QString::fromUtf8("Help"));

        horizontalLayout_33->addWidget(help_screencast_frames);


        gridLayoutFormatCodecs->addWidget(frameFrames, 1, 1, 1, 1);

        frame = new QFrame(frame_video);
        frame->setObjectName("frame");
        horizontalLayout_3 = new QHBoxLayout(frame);
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        horizontalLayout_3->setContentsMargins(-1, 0, -1, 0);
        checkBoxMouseCursorOnOff = new QCheckBox(frame);
        checkBoxMouseCursorOnOff->setObjectName("checkBoxMouseCursorOnOff");

        horizontalLayout_3->addWidget(checkBoxMouseCursorOnOff);


        gridLayoutFormatCodecs->addWidget(frame, 1, 2, 1, 1);

        labelFrames = new QLabel(frame_video);
        labelFrames->setObjectName("labelFrames");
        labelFrames->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayoutFormatCodecs->addWidget(labelFrames, 1, 0, 1, 1, Qt::AlignLeft);

        horizontalSpacer_5 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayoutFormatCodecs->addItem(horizontalSpacer_5, 2, 2, 1, 1);

        verticalLayout_30 = new QVBoxLayout();
        verticalLayout_30->setObjectName("verticalLayout_30");
        verticalLayout_30->setContentsMargins(6, -1, -1, -1);
        label_17 = new QLabel(frame_video);
        label_17->setObjectName("label_17");
        label_17->setText(QString::fromUtf8("mkv"));

        verticalLayout_30->addWidget(label_17);


        gridLayoutFormatCodecs->addLayout(verticalLayout_30, 2, 1, 1, 1);

        verticalLayout_29 = new QVBoxLayout();
        verticalLayout_29->setObjectName("verticalLayout_29");
        help_screencast_videocodec = new QToolButton(frame_video);
        help_screencast_videocodec->setObjectName("help_screencast_videocodec");
        help_screencast_videocodec->setText(QString::fromUtf8("Help"));

        verticalLayout_29->addWidget(help_screencast_videocodec, 0, Qt::AlignRight);


        gridLayoutFormatCodecs->addLayout(verticalLayout_29, 3, 3, 1, 1);

        horizontalSpacer = new QSpacerItem(40, 5, QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Minimum);

        gridLayoutFormatCodecs->addItem(horizontalSpacer, 0, 3, 1, 1);


        verticalLayout_8->addLayout(gridLayoutFormatCodecs);


        verticalLayout_7->addWidget(frame_video);

        line_3 = new QFrame(tabScreen);
        line_3->setObjectName("line_3");
        line_3->setStyleSheet(QString::fromUtf8("color: rgb(200, 200, 200);"));
        line_3->setFrameShadow(QFrame::Plain);
        line_3->setFrameShape(QFrame::Shape::HLine);

        verticalLayout_7->addWidget(line_3);

        horizontalLayout_10 = new QHBoxLayout();
        horizontalLayout_10->setObjectName("horizontalLayout_10");
        labelScreencastCountdownText = new QLabel(tabScreen);
        labelScreencastCountdownText->setObjectName("labelScreencastCountdownText");

        horizontalLayout_10->addWidget(labelScreencastCountdownText);

        horizontalSpacer_3 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_10->addItem(horizontalSpacer_3);

        help_screencast_countdown = new QToolButton(tabScreen);
        help_screencast_countdown->setObjectName("help_screencast_countdown");

        horizontalLayout_10->addWidget(help_screencast_countdown);


        verticalLayout_7->addLayout(horizontalLayout_10);


        horizontalLayout_15->addLayout(verticalLayout_7);

        line_5 = new QFrame(tabScreen);
        line_5->setObjectName("line_5");
        line_5->setStyleSheet(QString::fromUtf8("color: rgb(200, 200, 200);"));
        line_5->setFrameShadow(QFrame::Plain);
        line_5->setFrameShape(QFrame::Shape::VLine);

        horizontalLayout_15->addWidget(line_5);

        gridLayout_8 = new QGridLayout();
        gridLayout_8->setObjectName("gridLayout_8");
        gridLayout_8->setContentsMargins(-1, -1, -1, 10);
        verticalSpacer_22 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_8->addItem(verticalSpacer_22, 4, 0, 1, 1);

        gridLayout_9 = new QGridLayout();
        gridLayout_9->setObjectName("gridLayout_9");
        gridLayout_9->setContentsMargins(-1, 10, -1, -1);
        label_30 = new QLabel(tabScreen);
        label_30->setObjectName("label_30");
        label_30->setText(QString::fromUtf8("KB"));

        gridLayout_9->addWidget(label_30, 2, 3, 1, 1);

        label_29 = new QLabel(tabScreen);
        label_29->setObjectName("label_29");

        gridLayout_9->addWidget(label_29, 8, 1, 1, 1);

        labelInfoAudiocodec = new QLabel(tabScreen);
        labelInfoAudiocodec->setObjectName("labelInfoAudiocodec");
        labelInfoAudiocodec->setText(QString::fromUtf8(""));

        gridLayout_9->addWidget(labelInfoAudiocodec, 7, 2, 1, 2);

        label_19 = new QLabel(tabScreen);
        label_19->setObjectName("label_19");

        gridLayout_9->addWidget(label_19, 1, 1, 1, 1);

        label_27 = new QLabel(tabScreen);
        label_27->setObjectName("label_27");

        gridLayout_9->addWidget(label_27, 7, 1, 1, 1);

        labelInfoFrames = new QLabel(tabScreen);
        labelInfoFrames->setObjectName("labelInfoFrames");
        labelInfoFrames->setText(QString::fromUtf8(""));

        gridLayout_9->addWidget(labelInfoFrames, 8, 2, 1, 2);

        label_31 = new QLabel(tabScreen);
        label_31->setObjectName("label_31");

        gridLayout_9->addWidget(label_31, 5, 1, 1, 1);

        label_33 = new QLabel(tabScreen);
        label_33->setObjectName("label_33");

        gridLayout_9->addWidget(label_33, 0, 1, 1, 1);

        labelInfoFormat = new QLabel(tabScreen);
        labelInfoFormat->setObjectName("labelInfoFormat");
        labelInfoFormat->setText(QString::fromUtf8("mkv"));

        gridLayout_9->addWidget(labelInfoFormat, 5, 2, 1, 2);

        label_20 = new QLabel(tabScreen);
        label_20->setObjectName("label_20");

        gridLayout_9->addWidget(label_20, 2, 1, 1, 1);

        labelVideoSize = new QLabel(tabScreen);
        labelVideoSize->setObjectName("labelVideoSize");
        labelVideoSize->setText(QString::fromUtf8("0"));
        labelVideoSize->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_9->addWidget(labelVideoSize, 2, 2, 1, 1);

        label_28 = new QLabel(tabScreen);
        label_28->setObjectName("label_28");

        gridLayout_9->addWidget(label_28, 6, 1, 1, 1);

        line_4 = new QFrame(tabScreen);
        line_4->setObjectName("line_4");
        line_4->setStyleSheet(QString::fromUtf8("color: rgb(200, 200, 200);"));
        line_4->setFrameShadow(QFrame::Plain);
        line_4->setFrameShape(QFrame::Shape::HLine);

        gridLayout_9->addWidget(line_4, 4, 1, 1, 3);

        labelInfoRecordTime = new QLabel(tabScreen);
        labelInfoRecordTime->setObjectName("labelInfoRecordTime");
        labelInfoRecordTime->setText(QString::fromUtf8("00:00:00"));
        labelInfoRecordTime->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_9->addWidget(labelInfoRecordTime, 0, 2, 1, 2);

        label_32 = new QLabel(tabScreen);
        label_32->setObjectName("label_32");
        label_32->setText(QString::fromUtf8("MB"));

        gridLayout_9->addWidget(label_32, 1, 3, 1, 1);

        labelFreeSize = new QLabel(tabScreen);
        labelFreeSize->setObjectName("labelFreeSize");
        labelFreeSize->setMinimumSize(QSize(40, 0));
        labelFreeSize->setText(QString::fromUtf8("0"));
        labelFreeSize->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_9->addWidget(labelFreeSize, 1, 2, 1, 1);

        labelInfoVideocodec = new QLabel(tabScreen);
        labelInfoVideocodec->setObjectName("labelInfoVideocodec");
        labelInfoVideocodec->setText(QString::fromUtf8("H.264"));

        gridLayout_9->addWidget(labelInfoVideocodec, 6, 2, 1, 2);

        verticalSpacer_5 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_9->addItem(verticalSpacer_5, 9, 2, 1, 1);


        gridLayout_8->addLayout(gridLayout_9, 1, 0, 1, 1);

        label_18 = new QLabel(tabScreen);
        label_18->setObjectName("label_18");

        gridLayout_8->addWidget(label_18, 0, 0, 1, 1, Qt::AlignHCenter);

        label_Upate_tab_2 = new QLabel(tabScreen);
        label_Upate_tab_2->setObjectName("label_Upate_tab_2");
        label_Upate_tab_2->setText(QString::fromUtf8("TextLabel"));
        label_Upate_tab_2->setOpenExternalLinks(true);

        gridLayout_8->addWidget(label_Upate_tab_2, 2, 0, 1, 1, Qt::AlignHCenter);


        horizontalLayout_15->addLayout(gridLayout_8);

        tabWidgetScreencast->addTab(tabScreen, icon, QString());
        tabWidgetScreencast->setTabText(tabWidgetScreencast->indexOf(tabScreen), QString::fromUtf8(""));
        tabMisc = new QWidget();
        tabMisc->setObjectName("tabMisc");
        horizontalLayout_4 = new QHBoxLayout(tabMisc);
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        gridLayout_10 = new QGridLayout();
        gridLayout_10->setObjectName("gridLayout_10");
        horizontalLayout_25 = new QHBoxLayout();
        horizontalLayout_25->setObjectName("horizontalLayout_25");
        frameVideoPath = new QFrame(tabMisc);
        frameVideoPath->setObjectName("frameVideoPath");
        frameVideoPath->setFrameShape(QFrame::NoFrame);
        frameVideoPath->setFrameShadow(QFrame::Raised);
        horizontalLayout_20 = new QHBoxLayout(frameVideoPath);
        horizontalLayout_20->setObjectName("horizontalLayout_20");
        horizontalLayout_20->setContentsMargins(0, 0, -1, 0);
        LabelVideoPath = new QLabel(frameVideoPath);
        LabelVideoPath->setObjectName("LabelVideoPath");

        horizontalLayout_20->addWidget(LabelVideoPath);

        lineEditVideoPath = new QLineEdit(frameVideoPath);
        lineEditVideoPath->setObjectName("lineEditVideoPath");
        lineEditVideoPath->setText(QString::fromUtf8(""));
        lineEditVideoPath->setReadOnly(true);

        horizontalLayout_20->addWidget(lineEditVideoPath);

        toolButtonVideoPath = new QToolButton(frameVideoPath);
        toolButtonVideoPath->setObjectName("toolButtonVideoPath");
        toolButtonVideoPath->setText(QString::fromUtf8("..."));

        horizontalLayout_20->addWidget(toolButtonVideoPath);

        toolButtonVideoPathReset = new QToolButton(frameVideoPath);
        toolButtonVideoPathReset->setObjectName("toolButtonVideoPathReset");
        toolButtonVideoPathReset->setMinimumSize(QSize(0, 24));
        toolButtonVideoPathReset->setText(QString::fromUtf8("..."));
        toolButtonVideoPathReset->setIcon(icon5);

        horizontalLayout_20->addWidget(toolButtonVideoPathReset);


        horizontalLayout_25->addWidget(frameVideoPath);


        gridLayout_10->addLayout(horizontalLayout_25, 0, 0, 1, 1);

        verticalSpacer_2 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_10->addItem(verticalSpacer_2, 5, 0, 1, 1);

        widgetLanguageAndHelp = new QWidget(tabMisc);
        widgetLanguageAndHelp->setObjectName("widgetLanguageAndHelp");
        horizontalLayout_32 = new QHBoxLayout(widgetLanguageAndHelp);
        horizontalLayout_32->setObjectName("horizontalLayout_32");
        label_66 = new QLabel(widgetLanguageAndHelp);
        label_66->setObjectName("label_66");
        label_66->setMaximumSize(QSize(28, 28));
        label_66->setText(QString::fromUtf8(""));
        label_66->setPixmap(QPixmap(QString::fromUtf8(":/pictures/screencast/world.png")));
        label_66->setScaledContents(true);

        horizontalLayout_32->addWidget(label_66);

        comboBoxLanguage = new QComboBox(widgetLanguageAndHelp);
        comboBoxLanguage->setObjectName("comboBoxLanguage");
        comboBoxLanguage->setEditable(true);
        comboBoxLanguage->setCurrentText(QString::fromUtf8(""));
        comboBoxLanguage->setMaxVisibleItems(12);
        comboBoxLanguage->setPlaceholderText(QString::fromUtf8(""));

        horizontalLayout_32->addWidget(comboBoxLanguage);

        horizontalSpacer_52 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_32->addItem(horizontalSpacer_52);

        label_35 = new QLabel(widgetLanguageAndHelp);
        label_35->setObjectName("label_35");
        label_35->setMaximumSize(QSize(24, 24));
        label_35->setText(QString::fromUtf8(""));
        label_35->setPixmap(QPixmap(QString::fromUtf8(":/pictures/screencast/information.png")));
        label_35->setScaledContents(true);

        horizontalLayout_32->addWidget(label_35);

        comboBoxOnlineHelp = new QComboBox(widgetLanguageAndHelp);
        comboBoxOnlineHelp->addItem(QString());
        comboBoxOnlineHelp->setObjectName("comboBoxOnlineHelp");
        comboBoxOnlineHelp->setCurrentText(QString::fromUtf8("Automatically"));
        comboBoxOnlineHelp->setSizeAdjustPolicy(QComboBox::AdjustToContents);

        horizontalLayout_32->addWidget(comboBoxOnlineHelp);

        horizontalSpacer_29 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_32->addItem(horizontalSpacer_29);


        gridLayout_10->addWidget(widgetLanguageAndHelp, 4, 0, 1, 1);

        checkBoxResetAtNextStart = new QCheckBox(tabMisc);
        checkBoxResetAtNextStart->setObjectName("checkBoxResetAtNextStart");

        gridLayout_10->addWidget(checkBoxResetAtNextStart, 6, 0, 1, 1);

        horizontalLayout_7 = new QHBoxLayout();
        horizontalLayout_7->setObjectName("horizontalLayout_7");
        checkBoxShowInSystray = new QCheckBox(tabMisc);
        checkBoxShowInSystray->setObjectName("checkBoxShowInSystray");

        horizontalLayout_7->addWidget(checkBoxShowInSystray);

        horizontalSpacer_4 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_7->addItem(horizontalSpacer_4);


        gridLayout_10->addLayout(horizontalLayout_7, 1, 0, 1, 1);

        horizontalLayout_9 = new QHBoxLayout();
        horizontalLayout_9->setObjectName("horizontalLayout_9");
        horizontalLayout_9->setContentsMargins(-1, -1, 9, -1);
        label_34 = new QLabel(tabMisc);
        label_34->setObjectName("label_34");

        horizontalLayout_9->addWidget(label_34);

        horizontalSpacer_44 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_9->addItem(horizontalSpacer_44);


        gridLayout_10->addLayout(horizontalLayout_9, 3, 0, 1, 1);

        horizontalLayout_26 = new QHBoxLayout();
        horizontalLayout_26->setObjectName("horizontalLayout_26");
        checkBoxMinimizedWhenRecordingStarts = new QCheckBox(tabMisc);
        checkBoxMinimizedWhenRecordingStarts->setObjectName("checkBoxMinimizedWhenRecordingStarts");

        horizontalLayout_26->addWidget(checkBoxMinimizedWhenRecordingStarts);


        gridLayout_10->addLayout(horizontalLayout_26, 2, 0, 1, 1);


        horizontalLayout_4->addLayout(gridLayout_10);

        QIcon icon6;
        icon6.addFile(QString::fromUtf8(":/pictures/screencast/preferences-system.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        tabWidgetScreencast->addTab(tabMisc, icon6, QString());
        tabWidgetScreencast->setTabText(tabWidgetScreencast->indexOf(tabMisc), QString::fromUtf8(""));
        tabAvailable = new QWidget();
        tabAvailable->setObjectName("tabAvailable");
        horizontalLayout_5 = new QHBoxLayout(tabAvailable);
        horizontalLayout_5->setObjectName("horizontalLayout_5");
        verticalLayout_19 = new QVBoxLayout();
        verticalLayout_19->setSpacing(0);
        verticalLayout_19->setObjectName("verticalLayout_19");
        gridLayout_7 = new QGridLayout();
        gridLayout_7->setObjectName("gridLayout_7");
        label_24 = new QLabel(tabAvailable);
        label_24->setObjectName("label_24");
        QFont font;
        font.setBold(true);
        label_24->setFont(font);
        label_24->setText(QString::fromUtf8("Format"));

        gridLayout_7->addWidget(label_24, 0, 0, 1, 1, Qt::AlignHCenter);

        label_25 = new QLabel(tabAvailable);
        label_25->setObjectName("label_25");
        label_25->setFont(font);
        label_25->setText(QString::fromUtf8("Video"));

        gridLayout_7->addWidget(label_25, 0, 1, 1, 1, Qt::AlignHCenter);

        label_26 = new QLabel(tabAvailable);
        label_26->setObjectName("label_26");
        label_26->setFont(font);
        label_26->setText(QString::fromUtf8("Audio"));

        gridLayout_7->addWidget(label_26, 0, 2, 1, 1, Qt::AlignHCenter);


        verticalLayout_19->addLayout(gridLayout_7);

        scrollAreaAvailable = new QScrollArea(tabAvailable);
        scrollAreaAvailable->setObjectName("scrollAreaAvailable");
        scrollAreaAvailable->setMinimumSize(QSize(0, 100));
        scrollAreaAvailable->setWidgetResizable(true);
        scrollAreaWidgetContentsAvailable = new QWidget();
        scrollAreaWidgetContentsAvailable->setObjectName("scrollAreaWidgetContentsAvailable");
        scrollAreaWidgetContentsAvailable->setGeometry(QRect(0, 0, 20, 98));
        gridLayoutAvailable = new QGridLayout(scrollAreaWidgetContentsAvailable);
        gridLayoutAvailable->setSpacing(0);
        gridLayoutAvailable->setObjectName("gridLayoutAvailable");
        gridLayoutAvailable->setContentsMargins(0, -1, -1, -1);
        scrollAreaAvailable->setWidget(scrollAreaWidgetContentsAvailable);

        verticalLayout_19->addWidget(scrollAreaAvailable);


        horizontalLayout_5->addLayout(verticalLayout_19);

        verticalLayout_17 = new QVBoxLayout();
        verticalLayout_17->setObjectName("verticalLayout_17");
        verticalLayout_18 = new QVBoxLayout();
        verticalLayout_18->setObjectName("verticalLayout_18");
        label_21 = new QLabel(tabAvailable);
        label_21->setObjectName("label_21");
        label_21->setText(QString::fromUtf8(""));

        verticalLayout_18->addWidget(label_21);


        verticalLayout_17->addLayout(verticalLayout_18);

        horizontalLayout_8 = new QHBoxLayout();
        horizontalLayout_8->setObjectName("horizontalLayout_8");
        labelAvalible = new QLabel(tabAvailable);
        labelAvalible->setObjectName("labelAvalible");
        labelAvalible->setMaximumSize(QSize(16, 16));
        labelAvalible->setText(QString::fromUtf8(""));
        labelAvalible->setPixmap(QPixmap(QString::fromUtf8(":/pictures/screencast/accept.png")));
        labelAvalible->setScaledContents(true);

        horizontalLayout_8->addWidget(labelAvalible);

        label_22 = new QLabel(tabAvailable);
        label_22->setObjectName("label_22");

        horizontalLayout_8->addWidget(label_22, 0, Qt::AlignLeft);

        horizontalSpacer_7 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_8->addItem(horizontalSpacer_7);


        verticalLayout_17->addLayout(horizontalLayout_8);

        horizontalLayout_11 = new QHBoxLayout();
        horizontalLayout_11->setObjectName("horizontalLayout_11");
        labelNotAvailable = new QLabel(tabAvailable);
        labelNotAvailable->setObjectName("labelNotAvailable");
        labelNotAvailable->setMaximumSize(QSize(16, 16));
        labelNotAvailable->setText(QString::fromUtf8(""));
        labelNotAvailable->setPixmap(QPixmap(QString::fromUtf8(":/pictures/screencast/missing.png")));
        labelNotAvailable->setScaledContents(true);

        horizontalLayout_11->addWidget(labelNotAvailable);

        label_23 = new QLabel(tabAvailable);
        label_23->setObjectName("label_23");

        horizontalLayout_11->addWidget(label_23);

        horizontalSpacer_25 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_11->addItem(horizontalSpacer_25);


        verticalLayout_17->addLayout(horizontalLayout_11);

        verticalSpacer_9 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_17->addItem(verticalSpacer_9);


        horizontalLayout_5->addLayout(verticalLayout_17);

        verticalLayout_16 = new QVBoxLayout();
        verticalLayout_16->setObjectName("verticalLayout_16");
        help_screencast_avalaible = new QToolButton(tabAvailable);
        help_screencast_avalaible->setObjectName("help_screencast_avalaible");
        help_screencast_avalaible->setEnabled(false);
#if QT_CONFIG(tooltip)
        help_screencast_avalaible->setToolTip(QString::fromUtf8(""));
#endif // QT_CONFIG(tooltip)
        help_screencast_avalaible->setText(QString::fromUtf8("Help"));

        verticalLayout_16->addWidget(help_screencast_avalaible);

        verticalSpacer_8 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_16->addItem(verticalSpacer_8);


        horizontalLayout_5->addLayout(verticalLayout_16);

        horizontalLayout_5->setStretch(0, 1);
        QIcon icon7;
        icon7.addFile(QString::fromUtf8(":/pictures/screencast/supported-formats.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        tabWidgetScreencast->addTab(tabAvailable, icon7, QString());
        tabWidgetScreencast->setTabText(tabWidgetScreencast->indexOf(tabAvailable), QString::fromUtf8(""));
        tab = new QWidget();
        tab->setObjectName("tab");
        verticalLayout_42 = new QVBoxLayout(tab);
        verticalLayout_42->setObjectName("verticalLayout_42");
        verticalSpacer_30 = new QSpacerItem(20, 3, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_42->addItem(verticalSpacer_30);

        verticalSpacer_31 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_42->addItem(verticalSpacer_31);

        gridLayout_16 = new QGridLayout();
        gridLayout_16->setObjectName("gridLayout_16");
        labelAutorPicture = new QLabel(tab);
        labelAutorPicture->setObjectName("labelAutorPicture");
        labelAutorPicture->setMaximumSize(QSize(100, 100));
        labelAutorPicture->setText(QString::fromUtf8(""));
        labelAutorPicture->setPixmap(QPixmap(QString::fromUtf8(":/pictures/screencast/author.png")));
        labelAutorPicture->setScaledContents(true);
        labelAutorPicture->setAlignment(Qt::AlignCenter);

        gridLayout_16->addWidget(labelAutorPicture, 1, 1, 1, 1);

        verticalLayout_37 = new QVBoxLayout();
        verticalLayout_37->setObjectName("verticalLayout_37");
        labelSourcecodeUrl = new QLabel(tab);
        labelSourcecodeUrl->setObjectName("labelSourcecodeUrl");
        labelSourcecodeUrl->setText(QString::fromUtf8("Sourcecode"));
        labelSourcecodeUrl->setAlignment(Qt::AlignCenter);
        labelSourcecodeUrl->setOpenExternalLinks(true);

        verticalLayout_37->addWidget(labelSourcecodeUrl);

        labelWebSiteUrl = new QLabel(tab);
        labelWebSiteUrl->setObjectName("labelWebSiteUrl");
        labelWebSiteUrl->setText(QString::fromUtf8("Website"));
        labelWebSiteUrl->setAlignment(Qt::AlignCenter);
        labelWebSiteUrl->setOpenExternalLinks(true);

        verticalLayout_37->addWidget(labelWebSiteUrl);


        gridLayout_16->addLayout(verticalLayout_37, 1, 0, 1, 1);

        verticalLayout_38 = new QVBoxLayout();
        verticalLayout_38->setObjectName("verticalLayout_38");
        labelLanguageUrl = new QLabel(tab);
        labelLanguageUrl->setObjectName("labelLanguageUrl");
        labelLanguageUrl->setText(QString::fromUtf8("Translation"));
        labelLanguageUrl->setAlignment(Qt::AlignCenter);
        labelLanguageUrl->setOpenExternalLinks(true);

        verticalLayout_38->addWidget(labelLanguageUrl);

        labelDonateUrl = new QLabel(tab);
        labelDonateUrl->setObjectName("labelDonateUrl");
        labelDonateUrl->setText(QString::fromUtf8("Donate"));
        labelDonateUrl->setAlignment(Qt::AlignCenter);
        labelDonateUrl->setOpenExternalLinks(true);

        verticalLayout_38->addWidget(labelDonateUrl);


        gridLayout_16->addLayout(verticalLayout_38, 1, 2, 1, 1);


        verticalLayout_42->addLayout(gridLayout_16);

        verticalSpacer_28 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_42->addItem(verticalSpacer_28);

        line_14 = new QFrame(tab);
        line_14->setObjectName("line_14");
        line_14->setStyleSheet(QString::fromUtf8("color: rgb(200, 200, 200);"));
        line_14->setFrameShadow(QFrame::Plain);
        line_14->setFrameShape(QFrame::Shape::HLine);

        verticalLayout_42->addWidget(line_14);

        verticalSpacer_26 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_42->addItem(verticalSpacer_26);

        horizontalLayout_40 = new QHBoxLayout();
        horizontalLayout_40->setObjectName("horizontalLayout_40");
        horizontalSpacer_13 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_40->addItem(horizontalSpacer_13);

        pushButtonLicense = new QPushButton(tab);
        pushButtonLicense->setObjectName("pushButtonLicense");

        horizontalLayout_40->addWidget(pushButtonLicense);

        horizontalSpacer_15 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_40->addItem(horizontalSpacer_15);


        verticalLayout_42->addLayout(horizontalLayout_40);

        verticalSpacer_4 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_42->addItem(verticalSpacer_4);

        verticalSpacer_29 = new QSpacerItem(20, 4, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_42->addItem(verticalSpacer_29);

        horizontalLayout_63 = new QHBoxLayout();
        horizontalLayout_63->setObjectName("horizontalLayout_63");
        horizontalSpacer_56 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_63->addItem(horizontalSpacer_56);

        pushButtonImages = new QPushButton(tab);
        pushButtonImages->setObjectName("pushButtonImages");

        horizontalLayout_63->addWidget(pushButtonImages);

        horizontalSpacer_33 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_63->addItem(horizontalSpacer_33);


        verticalLayout_42->addLayout(horizontalLayout_63);

        label_save_image_path = new QLabel(tab);
        label_save_image_path->setObjectName("label_save_image_path");
        label_save_image_path->setText(QString::fromUtf8(""));

        verticalLayout_42->addWidget(label_save_image_path);

        line_cisco = new QFrame(tab);
        line_cisco->setObjectName("line_cisco");
        line_cisco->setFrameShape(QFrame::Shape::HLine);
        line_cisco->setFrameShadow(QFrame::Shadow::Sunken);

        verticalLayout_42->addWidget(line_cisco);

        frame_cisco = new QFrame(tab);
        frame_cisco->setObjectName("frame_cisco");
        frame_cisco->setFrameShape(QFrame::StyledPanel);
        frame_cisco->setFrameShadow(QFrame::Raised);
        verticalLayout_39 = new QVBoxLayout(frame_cisco);
        verticalLayout_39->setObjectName("verticalLayout_39");
        verticalLayout_39->setContentsMargins(-1, 0, -1, 0);
        gridLayout_17 = new QGridLayout();
        gridLayout_17->setObjectName("gridLayout_17");
        frame_2 = new QFrame(frame_cisco);
        frame_2->setObjectName("frame_2");
        frame_2->setFrameShape(QFrame::NoFrame);
        frame_2->setFrameShadow(QFrame::Sunken);
        verticalLayout_41 = new QVBoxLayout(frame_2);
        verticalLayout_41->setObjectName("verticalLayout_41");
        label_cisco_hint = new QLabel(frame_2);
        label_cisco_hint->setObjectName("label_cisco_hint");
        label_cisco_hint->setFont(font);
        label_cisco_hint->setText(QString::fromUtf8("OpenH264 Video Codec provided by Cisco Systems, Inc."));

        verticalLayout_41->addWidget(label_cisco_hint, 0, Qt::AlignHCenter);

        pushButtonCiscoLicense = new QPushButton(frame_2);
        pushButtonCiscoLicense->setObjectName("pushButtonCiscoLicense");

        verticalLayout_41->addWidget(pushButtonCiscoLicense, 0, Qt::AlignHCenter);

        label_openh264_homepage = new QLabel(frame_2);
        label_openh264_homepage->setObjectName("label_openh264_homepage");
        label_openh264_homepage->setText(QString::fromUtf8("<html><head/><body><p><a href=\"https://www.openh264.org\"><span style=\" text-decoration: underline; color:#2980b9;\">https://www.openh264.org</span></a></p></body></html>"));
        label_openh264_homepage->setOpenExternalLinks(true);

        verticalLayout_41->addWidget(label_openh264_homepage, 0, Qt::AlignHCenter);

        horizontalLayout_39 = new QHBoxLayout();
        horizontalLayout_39->setObjectName("horizontalLayout_39");
        horizontalSpacer_22 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_39->addItem(horizontalSpacer_22);

        radioButton_cisco_on = new QRadioButton(frame_2);
        radioButton_cisco_on->setObjectName("radioButton_cisco_on");

        horizontalLayout_39->addWidget(radioButton_cisco_on);

        radioButton_cisco_off = new QRadioButton(frame_2);
        radioButton_cisco_off->setObjectName("radioButton_cisco_off");

        horizontalLayout_39->addWidget(radioButton_cisco_off);

        horizontalSpacer_24 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_39->addItem(horizontalSpacer_24);


        verticalLayout_41->addLayout(horizontalLayout_39);


        gridLayout_17->addWidget(frame_2, 1, 0, 1, 2);


        verticalLayout_39->addLayout(gridLayout_17);


        verticalLayout_42->addWidget(frame_cisco);

        QIcon icon8;
        icon8.addFile(QString::fromUtf8(":/pictures/screencast/help-about.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        tabWidgetScreencast->addTab(tab, icon8, QString());
        tabWidgetScreencast->setTabText(tabWidgetScreencast->indexOf(tab), QString::fromUtf8(""));

        verticalLayout_2->addWidget(tabWidgetScreencast);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        pushButtonStart = new QPushButton(tab_sidebar_screeancast);
        pushButtonStart->setObjectName("pushButtonStart");
        pushButtonStart->setFont(font);
#if QT_CONFIG(tooltip)
        pushButtonStart->setToolTip(QString::fromUtf8(""));
#endif // QT_CONFIG(tooltip)

        horizontalLayout_2->addWidget(pushButtonStart);

        pushButtonStop = new QPushButton(tab_sidebar_screeancast);
        pushButtonStop->setObjectName("pushButtonStop");
        pushButtonStop->setEnabled(false);
        pushButtonStop->setFont(font);
#if QT_CONFIG(tooltip)
        pushButtonStop->setToolTip(QString::fromUtf8(""));
#endif // QT_CONFIG(tooltip)

        horizontalLayout_2->addWidget(pushButtonStop);

        pushButtonPause = new QPushButton(tab_sidebar_screeancast);
        pushButtonPause->setObjectName("pushButtonPause");
        pushButtonPause->setEnabled(false);
        pushButtonPause->setFont(font);

        horizontalLayout_2->addWidget(pushButtonPause);

        pushButtonContinue = new QPushButton(tab_sidebar_screeancast);
        pushButtonContinue->setObjectName("pushButtonContinue");
        pushButtonContinue->setFont(font);

        horizontalLayout_2->addWidget(pushButtonContinue);

        pushButtonOpenfolder = new QPushButton(tab_sidebar_screeancast);
        pushButtonOpenfolder->setObjectName("pushButtonOpenfolder");
        pushButtonOpenfolder->setFont(font);

        horizontalLayout_2->addWidget(pushButtonOpenfolder);

        horizontalSpacer_10 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_10);

        pushButtonSnapshot_2 = new QPushButton(tab_sidebar_screeancast);
        pushButtonSnapshot_2->setObjectName("pushButtonSnapshot_2");
        pushButtonSnapshot_2->setFont(font);

        horizontalLayout_2->addWidget(pushButtonSnapshot_2);

        pushButtonSnapshotOpenFolder_2 = new QPushButton(tab_sidebar_screeancast);
        pushButtonSnapshotOpenFolder_2->setObjectName("pushButtonSnapshotOpenFolder_2");
        pushButtonSnapshotOpenFolder_2->setFont(font);

        horizontalLayout_2->addWidget(pushButtonSnapshotOpenFolder_2);


        verticalLayout_2->addLayout(horizontalLayout_2);

        tabWidgetSideBar->addTab(tab_sidebar_screeancast, QString());
        tabWidgetSideBar->setTabText(tabWidgetSideBar->indexOf(tab_sidebar_screeancast), QString::fromUtf8(""));
        tabSidebarCamera = new QWidget();
        tabSidebarCamera->setObjectName("tabSidebarCamera");
        verticalLayout_10 = new QVBoxLayout(tabSidebarCamera);
        verticalLayout_10->setSpacing(0);
        verticalLayout_10->setObjectName("verticalLayout_10");
        verticalLayout_10->setContentsMargins(0, 0, 0, 0);
        tabWidgetCamera = new QTabWidget(tabSidebarCamera);
        tabWidgetCamera->setObjectName("tabWidgetCamera");
        tabWidgetCamera->setIconSize(QSize(48, 48));
        tabCamera = new QWidget();
        tabCamera->setObjectName("tabCamera");
        verticalLayout_11 = new QVBoxLayout(tabCamera);
        verticalLayout_11->setObjectName("verticalLayout_11");
        label_4 = new QLabel(tabCamera);
        label_4->setObjectName("label_4");
        QFont font1;
        font1.setPointSize(14);
        label_4->setFont(font1);
        label_4->setStyleSheet(QString::fromUtf8(""));

        verticalLayout_11->addWidget(label_4, 0, Qt::AlignHCenter);

        line_9 = new QFrame(tabCamera);
        line_9->setObjectName("line_9");
        line_9->setStyleSheet(QString::fromUtf8("color: rgb(200, 200, 200);"));
        line_9->setFrameShadow(QFrame::Plain);
        line_9->setFrameShape(QFrame::Shape::HLine);

        verticalLayout_11->addWidget(line_9);

        gridLayout_3 = new QGridLayout();
        gridLayout_3->setObjectName("gridLayout_3");
        layoutAllCameras = new QVBoxLayout();
        layoutAllCameras->setObjectName("layoutAllCameras");
        gridLayout_4 = new QGridLayout();
        gridLayout_4->setObjectName("gridLayout_4");
        gridLayout_4->setVerticalSpacing(9);
        gridLayout_4->setContentsMargins(0, -1, -1, 0);
        help_camera_camera = new QToolButton(tabCamera);
        help_camera_camera->setObjectName("help_camera_camera");
        help_camera_camera->setText(QString::fromUtf8("Help"));

        gridLayout_4->addWidget(help_camera_camera, 0, 3, 1, 1, Qt::AlignTop);

        label_camera_window_zoom = new QLabel(tabCamera);
        label_camera_window_zoom->setObjectName("label_camera_window_zoom");
        label_camera_window_zoom->setMinimumSize(QSize(34, 34));
        label_camera_window_zoom->setMaximumSize(QSize(34, 34));
        label_camera_window_zoom->setText(QString::fromUtf8(""));
        label_camera_window_zoom->setPixmap(QPixmap(QString::fromUtf8(":/pictures/systray/magnification.png")));
        label_camera_window_zoom->setScaledContents(true);

        gridLayout_4->addWidget(label_camera_window_zoom, 2, 0, 1, 1);

        horizontalLayout_16 = new QHBoxLayout();
        horizontalLayout_16->setObjectName("horizontalLayout_16");
        horizontalLayout_16->setContentsMargins(0, -1, -1, -1);
        checkBoxCameraInvert = new QCheckBox(tabCamera);
        checkBoxCameraInvert->setObjectName("checkBoxCameraInvert");
        checkBoxCameraInvert->setEnabled(false);

        horizontalLayout_16->addWidget(checkBoxCameraInvert);

        horizontalSpacer_39 = new QSpacerItem(40, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Minimum);

        horizontalLayout_16->addItem(horizontalSpacer_39);

        checkBoxCameraGray = new QCheckBox(tabCamera);
        checkBoxCameraGray->setObjectName("checkBoxCameraGray");
        checkBoxCameraGray->setEnabled(false);

        horizontalLayout_16->addWidget(checkBoxCameraGray);

        horizontalSpacer_40 = new QSpacerItem(40, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Minimum);

        horizontalLayout_16->addItem(horizontalSpacer_40);

        checkBoxCameraMono = new QCheckBox(tabCamera);
        checkBoxCameraMono->setObjectName("checkBoxCameraMono");
        checkBoxCameraMono->setEnabled(false);

        horizontalLayout_16->addWidget(checkBoxCameraMono);

        horizontalSpacer_34 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_16->addItem(horizontalSpacer_34);


        gridLayout_4->addLayout(horizontalLayout_16, 6, 0, 1, 3);

        horizontalLayout_zoom = new QHBoxLayout();
        horizontalLayout_zoom->setSpacing(12);
        horizontalLayout_zoom->setObjectName("horizontalLayout_zoom");
        horizontalLayout_zoom->setContentsMargins(0, -1, -1, -1);

        gridLayout_4->addLayout(horizontalLayout_zoom, 2, 1, 1, 2);

        horizontalLayout_64 = new QHBoxLayout();
        horizontalLayout_64->setObjectName("horizontalLayout_64");
        horizontalLayout_64->setContentsMargins(0, -1, -1, -1);
        checkBoxCameraOnOff = new QCheckBox(tabCamera);
        checkBoxCameraOnOff->setObjectName("checkBoxCameraOnOff");
        checkBoxCameraOnOff->setEnabled(false);
#if QT_CONFIG(tooltip)
        checkBoxCameraOnOff->setToolTip(QString::fromUtf8("CTRL+SHIFT+F8"));
#endif // QT_CONFIG(tooltip)

        horizontalLayout_64->addWidget(checkBoxCameraOnOff);

        comboBoxCamera = new QComboBox(tabCamera);
        comboBoxCamera->setObjectName("comboBoxCamera");
        comboBoxCamera->setEnabled(false);
        QSizePolicy sizePolicy1(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(comboBoxCamera->sizePolicy().hasHeightForWidth());
        comboBoxCamera->setSizePolicy(sizePolicy1);
        comboBoxCamera->setCurrentText(QString::fromUtf8(""));
        comboBoxCamera->setSizeAdjustPolicy(QComboBox::AdjustToContents);

        horizontalLayout_64->addWidget(comboBoxCamera);

        comboBoxCameraResolution = new QComboBox(tabCamera);
        comboBoxCameraResolution->setObjectName("comboBoxCameraResolution");
        comboBoxCameraResolution->setEnabled(false);
        comboBoxCameraResolution->setSizeAdjustPolicy(QComboBox::AdjustToContents);

        horizontalLayout_64->addWidget(comboBoxCameraResolution);


        gridLayout_4->addLayout(horizontalLayout_64, 0, 0, 1, 3);

        horizontalLayout_66 = new QHBoxLayout();
        horizontalLayout_66->setObjectName("horizontalLayout_66");
        horizontalLayout_66->setContentsMargins(0, -1, -1, -1);
        horizontalLayout_45 = new QHBoxLayout();
        horizontalLayout_45->setSpacing(12);
        horizontalLayout_45->setObjectName("horizontalLayout_45");

        horizontalLayout_66->addLayout(horizontalLayout_45);

        labelCameraWindowSize = new QLabel(tabCamera);
        labelCameraWindowSize->setObjectName("labelCameraWindowSize");
        labelCameraWindowSize->setEnabled(true);
        labelCameraWindowSize->setText(QString::fromUtf8("---x---"));
        labelCameraWindowSize->setAlignment(Qt::AlignCenter);

        horizontalLayout_66->addWidget(labelCameraWindowSize);


        gridLayout_4->addLayout(horizontalLayout_66, 1, 1, 1, 2);

        label_camera_window_resize = new QLabel(tabCamera);
        label_camera_window_resize->setObjectName("label_camera_window_resize");
        label_camera_window_resize->setEnabled(true);
        label_camera_window_resize->setMaximumSize(QSize(34, 34));
        label_camera_window_resize->setText(QString::fromUtf8(""));
        label_camera_window_resize->setPixmap(QPixmap(QString::fromUtf8(":/pictures/camera/window-resize.png")));
        label_camera_window_resize->setScaledContents(true);

        gridLayout_4->addWidget(label_camera_window_resize, 1, 0, 1, 1);

        horizontalLayout_17 = new QHBoxLayout();
        horizontalLayout_17->setObjectName("horizontalLayout_17");
        horizontalLayout_17->setContentsMargins(0, -1, -1, -1);
        checkBoxCameraMirrorVertical = new QCheckBox(tabCamera);
        checkBoxCameraMirrorVertical->setObjectName("checkBoxCameraMirrorVertical");
        checkBoxCameraMirrorVertical->setEnabled(false);

        horizontalLayout_17->addWidget(checkBoxCameraMirrorVertical);

        horizontalSpacer_38 = new QSpacerItem(40, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Minimum);

        horizontalLayout_17->addItem(horizontalSpacer_38);

        checkBoxCameraMirrorHorizontal = new QCheckBox(tabCamera);
        checkBoxCameraMirrorHorizontal->setObjectName("checkBoxCameraMirrorHorizontal");
        checkBoxCameraMirrorHorizontal->setEnabled(false);

        horizontalLayout_17->addWidget(checkBoxCameraMirrorHorizontal);

        horizontalSpacer_9 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_17->addItem(horizontalSpacer_9);


        gridLayout_4->addLayout(horizontalLayout_17, 5, 0, 1, 3);

        horizontalLayout_65 = new QHBoxLayout();
        horizontalLayout_65->setSpacing(0);
        horizontalLayout_65->setObjectName("horizontalLayout_65");
        horizontalLayout_65->setContentsMargins(0, -1, -1, -1);
        horizontalSpacer_41 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_65->addItem(horizontalSpacer_41);

        toolButton_camera_view_rectangle = new QToolButton(tabCamera);
        toolButton_camera_view_rectangle->setObjectName("toolButton_camera_view_rectangle");
        toolButton_camera_view_rectangle->setText(QString::fromUtf8(""));
        QIcon icon9;
        icon9.addFile(QString::fromUtf8(":/pictures/camera/window-rectangle-off.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        icon9.addFile(QString::fromUtf8(":/pictures/camera/window-rectangle-on.png"), QSize(), QIcon::Mode::Normal, QIcon::State::On);
        toolButton_camera_view_rectangle->setIcon(icon9);
        toolButton_camera_view_rectangle->setIconSize(QSize(34, 34));
        toolButton_camera_view_rectangle->setCheckable(true);
        toolButton_camera_view_rectangle->setChecked(true);
        toolButton_camera_view_rectangle->setAutoExclusive(true);
        toolButton_camera_view_rectangle->setAutoRaise(true);

        horizontalLayout_65->addWidget(toolButton_camera_view_rectangle);

        horizontalSpacer_35 = new QSpacerItem(40, 20, QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Minimum);

        horizontalLayout_65->addItem(horizontalSpacer_35);

        toolButton_camera_view_ellipse = new QToolButton(tabCamera);
        toolButton_camera_view_ellipse->setObjectName("toolButton_camera_view_ellipse");
        toolButton_camera_view_ellipse->setText(QString::fromUtf8(""));
        QIcon icon10;
        icon10.addFile(QString::fromUtf8(":/pictures/camera/window-ellipse-off.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        icon10.addFile(QString::fromUtf8(":/pictures/camera/window-ellipse-on.png"), QSize(), QIcon::Mode::Normal, QIcon::State::On);
        toolButton_camera_view_ellipse->setIcon(icon10);
        toolButton_camera_view_ellipse->setIconSize(QSize(34, 34));
        toolButton_camera_view_ellipse->setCheckable(true);
        toolButton_camera_view_ellipse->setAutoExclusive(true);
        toolButton_camera_view_ellipse->setAutoRaise(true);

        horizontalLayout_65->addWidget(toolButton_camera_view_ellipse);

        horizontalSpacer_36 = new QSpacerItem(40, 20, QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Minimum);

        horizontalLayout_65->addItem(horizontalSpacer_36);

        toolButton_camera_view_circle = new QToolButton(tabCamera);
        toolButton_camera_view_circle->setObjectName("toolButton_camera_view_circle");
        toolButton_camera_view_circle->setText(QString::fromUtf8(""));
        QIcon icon11;
        icon11.addFile(QString::fromUtf8(":/pictures/camera/window-circle-off.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        icon11.addFile(QString::fromUtf8(":/pictures/camera/window-circle-on.png"), QSize(), QIcon::Mode::Normal, QIcon::State::On);
        toolButton_camera_view_circle->setIcon(icon11);
        toolButton_camera_view_circle->setIconSize(QSize(34, 34));
        toolButton_camera_view_circle->setCheckable(true);
        toolButton_camera_view_circle->setAutoExclusive(true);
        toolButton_camera_view_circle->setAutoRaise(true);

        horizontalLayout_65->addWidget(toolButton_camera_view_circle);

        horizontalSpacer_37 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_65->addItem(horizontalSpacer_37);


        gridLayout_4->addLayout(horizontalLayout_65, 3, 0, 1, 3);

        horizontalLayout_42 = new QHBoxLayout();
        horizontalLayout_42->setObjectName("horizontalLayout_42");
        horizontalLayout_42->setContentsMargins(0, -1, -1, -1);
        checkBoxCameraWindowFrame = new QCheckBox(tabCamera);
        checkBoxCameraWindowFrame->setObjectName("checkBoxCameraWindowFrame");
        checkBoxCameraWindowFrame->setEnabled(false);

        horizontalLayout_42->addWidget(checkBoxCameraWindowFrame);


        gridLayout_4->addLayout(horizontalLayout_42, 4, 0, 1, 3);


        layoutAllCameras->addLayout(gridLayout_4);

        verticalSpacer_6 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        layoutAllCameras->addItem(verticalSpacer_6);


        gridLayout_3->addLayout(layoutAllCameras, 0, 0, 1, 1);


        verticalLayout_11->addLayout(gridLayout_3);

        tabWidgetCamera->addTab(tabCamera, icon1, QString());
        tabWidgetCamera->setTabText(tabWidgetCamera->indexOf(tabCamera), QString::fromUtf8(""));

        verticalLayout_10->addWidget(tabWidgetCamera);

        tabWidgetSideBar->addTab(tabSidebarCamera, QString());
        tabWidgetSideBar->setTabText(tabWidgetSideBar->indexOf(tabSidebarCamera), QString::fromUtf8(""));
        tab_sidebar_snapshot = new QWidget();
        tab_sidebar_snapshot->setObjectName("tab_sidebar_snapshot");
        verticalLayout_12 = new QVBoxLayout(tab_sidebar_snapshot);
        verticalLayout_12->setSpacing(0);
        verticalLayout_12->setObjectName("verticalLayout_12");
        verticalLayout_12->setContentsMargins(0, 0, 0, 0);
        tabWidgetSnapshot = new QTabWidget(tab_sidebar_snapshot);
        tabWidgetSnapshot->setObjectName("tabWidgetSnapshot");
        tabWidgetSnapshot->setIconSize(QSize(48, 48));
        tab_2 = new QWidget();
        tab_2->setObjectName("tab_2");
        verticalLayout_13 = new QVBoxLayout(tab_2);
        verticalLayout_13->setObjectName("verticalLayout_13");
        label_2 = new QLabel(tab_2);
        label_2->setObjectName("label_2");
        label_2->setFont(font1);
        label_2->setText(QString::fromUtf8("Snapshot"));

        verticalLayout_13->addWidget(label_2, 0, Qt::AlignHCenter);

        line = new QFrame(tab_2);
        line->setObjectName("line");
        line->setStyleSheet(QString::fromUtf8("color: rgb(200, 200, 200);"));
        line->setFrameShadow(QFrame::Plain);
        line->setFrameShape(QFrame::Shape::HLine);

        verticalLayout_13->addWidget(line);

        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        horizontalLayout_44 = new QHBoxLayout();
        horizontalLayout_44->setObjectName("horizontalLayout_44");
        comboBoxSnapshotImageFormats = new QComboBox(tab_2);
        comboBoxSnapshotImageFormats->setObjectName("comboBoxSnapshotImageFormats");

        horizontalLayout_44->addWidget(comboBoxSnapshotImageFormats);

        toolButtonSnapshotFormatsReset = new QToolButton(tab_2);
        toolButtonSnapshotFormatsReset->setObjectName("toolButtonSnapshotFormatsReset");
        toolButtonSnapshotFormatsReset->setText(QString::fromUtf8(""));
        toolButtonSnapshotFormatsReset->setIcon(icon5);

        horizontalLayout_44->addWidget(toolButtonSnapshotFormatsReset);

        horizontalSpacer_26 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_44->addItem(horizontalSpacer_26);


        gridLayout->addLayout(horizontalLayout_44, 2, 1, 1, 1);

        label_57 = new QLabel(tab_2);
        label_57->setObjectName("label_57");

        gridLayout->addWidget(label_57, 2, 0, 1, 1);

        checkBox_snapshot_interactive = new QCheckBox(tab_2);
        checkBox_snapshot_interactive->setObjectName("checkBox_snapshot_interactive");
        checkBox_snapshot_interactive->setText(QString::fromUtf8("Interactive"));

        gridLayout->addWidget(checkBox_snapshot_interactive, 6, 0, 1, 2);

        horizontalLayout_59 = new QHBoxLayout();
        horizontalLayout_59->setObjectName("horizontalLayout_59");
        label_60 = new QLabel(tab_2);
        label_60->setObjectName("label_60");

        horizontalLayout_59->addWidget(label_60);

        toolButtonSnapshotSecondsWaitBeforeRecordingReset = new QToolButton(tab_2);
        toolButtonSnapshotSecondsWaitBeforeRecordingReset->setObjectName("toolButtonSnapshotSecondsWaitBeforeRecordingReset");
        toolButtonSnapshotSecondsWaitBeforeRecordingReset->setText(QString::fromUtf8(""));
        toolButtonSnapshotSecondsWaitBeforeRecordingReset->setIcon(icon5);

        horizontalLayout_59->addWidget(toolButtonSnapshotSecondsWaitBeforeRecordingReset);

        horizontalSpacer_12 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_59->addItem(horizontalSpacer_12);


        gridLayout->addLayout(horizontalLayout_59, 3, 0, 1, 2);

        horizontalLayout_24 = new QHBoxLayout();
        horizontalLayout_24->setObjectName("horizontalLayout_24");
        checkBoxSnapshotHideBeforeRecording = new QCheckBox(tab_2);
        checkBoxSnapshotHideBeforeRecording->setObjectName("checkBoxSnapshotHideBeforeRecording");

        horizontalLayout_24->addWidget(checkBoxSnapshotHideBeforeRecording);

        toolButtonSnapshotHideBeforeRecordingReset = new QToolButton(tab_2);
        toolButtonSnapshotHideBeforeRecordingReset->setObjectName("toolButtonSnapshotHideBeforeRecordingReset");
        toolButtonSnapshotHideBeforeRecordingReset->setText(QString::fromUtf8(""));
        toolButtonSnapshotHideBeforeRecordingReset->setIcon(icon5);

        horizontalLayout_24->addWidget(toolButtonSnapshotHideBeforeRecordingReset);

        horizontalSpacer_11 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_24->addItem(horizontalSpacer_11);


        gridLayout->addLayout(horizontalLayout_24, 4, 0, 1, 2);

        checkBoxSnapshotShowBallonInSystray = new QCheckBox(tab_2);
        checkBoxSnapshotShowBallonInSystray->setObjectName("checkBoxSnapshotShowBallonInSystray");

        gridLayout->addWidget(checkBoxSnapshotShowBallonInSystray, 5, 0, 1, 2);


        verticalLayout_13->addLayout(gridLayout);

        verticalSpacer_7 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_13->addItem(verticalSpacer_7);

        horizontalLayout_14 = new QHBoxLayout();
        horizontalLayout_14->setObjectName("horizontalLayout_14");
        horizontalSpacer_8 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_14->addItem(horizontalSpacer_8);

        pushButtonSnapshotOpenFolder = new QPushButton(tab_2);
        pushButtonSnapshotOpenFolder->setObjectName("pushButtonSnapshotOpenFolder");
        pushButtonSnapshotOpenFolder->setFont(font);

        horizontalLayout_14->addWidget(pushButtonSnapshotOpenFolder);

        pushButtonSnapshot = new QPushButton(tab_2);
        pushButtonSnapshot->setObjectName("pushButtonSnapshot");
        pushButtonSnapshot->setFont(font);

        horizontalLayout_14->addWidget(pushButtonSnapshot);


        verticalLayout_13->addLayout(horizontalLayout_14);

        tabWidgetSnapshot->addTab(tab_2, icon2, QString());
        tabWidgetSnapshot->setTabText(tabWidgetSnapshot->indexOf(tab_2), QString::fromUtf8(""));

        verticalLayout_12->addWidget(tabWidgetSnapshot);

        tabWidgetSideBar->addTab(tab_sidebar_snapshot, QString());
        tabWidgetSideBar->setTabText(tabWidgetSideBar->indexOf(tab_sidebar_snapshot), QString::fromUtf8(""));
        tab_3 = new QWidget();
        tab_3->setObjectName("tab_3");
        verticalLayout_21 = new QVBoxLayout(tab_3);
        verticalLayout_21->setObjectName("verticalLayout_21");
        verticalLayout_21->setContentsMargins(0, 0, 0, 0);
        tabWidgetConvert = new QTabWidget(tab_3);
        tabWidgetConvert->setObjectName("tabWidgetConvert");
        tabWidgetConvert->setIconSize(QSize(48, 48));
        tab_5 = new QWidget();
        tab_5->setObjectName("tab_5");
        verticalLayout_23 = new QVBoxLayout(tab_5);
        verticalLayout_23->setObjectName("verticalLayout_23");
        label_14 = new QLabel(tab_5);
        label_14->setObjectName("label_14");
        label_14->setFont(font1);
        label_14->setText(QString::fromUtf8("Convert"));

        verticalLayout_23->addWidget(label_14, 0, Qt::AlignHCenter);

        gridLayout_5 = new QGridLayout();
        gridLayout_5->setObjectName("gridLayout_5");
        line_11 = new QFrame(tab_5);
        line_11->setObjectName("line_11");
        line_11->setFrameShape(QFrame::Shape::HLine);
        line_11->setFrameShadow(QFrame::Shadow::Sunken);

        gridLayout_5->addWidget(line_11, 4, 0, 1, 4);

        verticalLayout_25 = new QVBoxLayout();
        verticalLayout_25->setSpacing(2);
        verticalLayout_25->setObjectName("verticalLayout_25");
        horizontalLayout_21 = new QHBoxLayout();
        horizontalLayout_21->setObjectName("horizontalLayout_21");
        lineEdit_convert_mkv_to_gif = new QLineEdit(tab_5);
        lineEdit_convert_mkv_to_gif->setObjectName("lineEdit_convert_mkv_to_gif");
        lineEdit_convert_mkv_to_gif->setText(QString::fromUtf8(""));
        lineEdit_convert_mkv_to_gif->setReadOnly(true);

        horizontalLayout_21->addWidget(lineEdit_convert_mkv_to_gif);

        toolButton_convert_dialog_mkv_to_gif = new QToolButton(tab_5);
        toolButton_convert_dialog_mkv_to_gif->setObjectName("toolButton_convert_dialog_mkv_to_gif");
        toolButton_convert_dialog_mkv_to_gif->setText(QString::fromUtf8("..."));

        horizontalLayout_21->addWidget(toolButton_convert_dialog_mkv_to_gif);

        pushButton_convert_mkv_to_gif = new QPushButton(tab_5);
        pushButton_convert_mkv_to_gif->setObjectName("pushButton_convert_mkv_to_gif");
        pushButton_convert_mkv_to_gif->setEnabled(false);
        pushButton_convert_mkv_to_gif->setText(QString::fromUtf8(""));
        QIcon icon12;
        icon12.addFile(QString::fromUtf8(":/pictures/screencast/accept.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        pushButton_convert_mkv_to_gif->setIcon(icon12);

        horizontalLayout_21->addWidget(pushButton_convert_mkv_to_gif);


        verticalLayout_25->addLayout(horizontalLayout_21);

        widget_convert_mkv_to_gif = new QWidget(tab_5);
        widget_convert_mkv_to_gif->setObjectName("widget_convert_mkv_to_gif");
        widget_convert_mkv_to_gif->setStyleSheet(QString::fromUtf8(""));
        horizontalLayout_22 = new QHBoxLayout(widget_convert_mkv_to_gif);
        horizontalLayout_22->setSpacing(0);
        horizontalLayout_22->setObjectName("horizontalLayout_22");
        horizontalLayout_22->setContentsMargins(0, 0, 0, 0);
        label_convert_mkv_to_gif = new QLabel(widget_convert_mkv_to_gif);
        label_convert_mkv_to_gif->setObjectName("label_convert_mkv_to_gif");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Preferred);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(label_convert_mkv_to_gif->sizePolicy().hasHeightForWidth());
        label_convert_mkv_to_gif->setSizePolicy(sizePolicy2);
        label_convert_mkv_to_gif->setText(QString::fromUtf8("Please select a file"));

        horizontalLayout_22->addWidget(label_convert_mkv_to_gif, 0, Qt::AlignHCenter);


        verticalLayout_25->addWidget(widget_convert_mkv_to_gif);


        gridLayout_5->addLayout(verticalLayout_25, 3, 3, 1, 1);

        label_15 = new QLabel(tab_5);
        label_15->setObjectName("label_15");
        label_15->setFont(font1);
        label_15->setText(QString::fromUtf8("Repair"));

        gridLayout_5->addWidget(label_15, 7, 0, 1, 4, Qt::AlignHCenter);

        verticalLayout_24 = new QVBoxLayout();
        verticalLayout_24->setSpacing(2);
        verticalLayout_24->setObjectName("verticalLayout_24");
        verticalLayout_24->setContentsMargins(-1, 0, -1, -1);
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        lineEdit_convert_mkv_to_mp4 = new QLineEdit(tab_5);
        lineEdit_convert_mkv_to_mp4->setObjectName("lineEdit_convert_mkv_to_mp4");
        lineEdit_convert_mkv_to_mp4->setText(QString::fromUtf8(""));
        lineEdit_convert_mkv_to_mp4->setReadOnly(true);

        horizontalLayout->addWidget(lineEdit_convert_mkv_to_mp4);

        toolButton_convert_dialog_mkv_to_mp4 = new QToolButton(tab_5);
        toolButton_convert_dialog_mkv_to_mp4->setObjectName("toolButton_convert_dialog_mkv_to_mp4");
        toolButton_convert_dialog_mkv_to_mp4->setText(QString::fromUtf8("..."));

        horizontalLayout->addWidget(toolButton_convert_dialog_mkv_to_mp4);

        pushButton_convert_mkv_to_mp4 = new QPushButton(tab_5);
        pushButton_convert_mkv_to_mp4->setObjectName("pushButton_convert_mkv_to_mp4");
        pushButton_convert_mkv_to_mp4->setEnabled(false);
        pushButton_convert_mkv_to_mp4->setText(QString::fromUtf8(""));
        pushButton_convert_mkv_to_mp4->setIcon(icon12);

        horizontalLayout->addWidget(pushButton_convert_mkv_to_mp4);


        verticalLayout_24->addLayout(horizontalLayout);

        widget_convert_mkv_to_mp4 = new QWidget(tab_5);
        widget_convert_mkv_to_mp4->setObjectName("widget_convert_mkv_to_mp4");
        widget_convert_mkv_to_mp4->setStyleSheet(QString::fromUtf8(""));
        horizontalLayout_19 = new QHBoxLayout(widget_convert_mkv_to_mp4);
        horizontalLayout_19->setSpacing(0);
        horizontalLayout_19->setObjectName("horizontalLayout_19");
        horizontalLayout_19->setContentsMargins(0, 0, 0, 0);
        label_convert_mkv_to_mp4 = new QLabel(widget_convert_mkv_to_mp4);
        label_convert_mkv_to_mp4->setObjectName("label_convert_mkv_to_mp4");
        sizePolicy2.setHeightForWidth(label_convert_mkv_to_mp4->sizePolicy().hasHeightForWidth());
        label_convert_mkv_to_mp4->setSizePolicy(sizePolicy2);
        label_convert_mkv_to_mp4->setText(QString::fromUtf8("Please select a file"));

        horizontalLayout_19->addWidget(label_convert_mkv_to_mp4, 0, Qt::AlignHCenter);


        verticalLayout_24->addWidget(widget_convert_mkv_to_mp4);


        gridLayout_5->addLayout(verticalLayout_24, 1, 3, 1, 1);

        line_10 = new QFrame(tab_5);
        line_10->setObjectName("line_10");
        line_10->setFrameShape(QFrame::Shape::HLine);
        line_10->setFrameShadow(QFrame::Shadow::Sunken);

        gridLayout_5->addWidget(line_10, 2, 0, 1, 4);

        verticalLayout_27 = new QVBoxLayout();
        verticalLayout_27->setSpacing(2);
        verticalLayout_27->setObjectName("verticalLayout_27");
        horizontalLayout_36 = new QHBoxLayout();
        horizontalLayout_36->setObjectName("horizontalLayout_36");
        lineEdit_convert_mkv_to_webm = new QLineEdit(tab_5);
        lineEdit_convert_mkv_to_webm->setObjectName("lineEdit_convert_mkv_to_webm");
        lineEdit_convert_mkv_to_webm->setText(QString::fromUtf8(""));
        lineEdit_convert_mkv_to_webm->setReadOnly(true);

        horizontalLayout_36->addWidget(lineEdit_convert_mkv_to_webm);

        toolButton_convert_dialog_mkv_to_webm = new QToolButton(tab_5);
        toolButton_convert_dialog_mkv_to_webm->setObjectName("toolButton_convert_dialog_mkv_to_webm");
        toolButton_convert_dialog_mkv_to_webm->setText(QString::fromUtf8("..."));

        horizontalLayout_36->addWidget(toolButton_convert_dialog_mkv_to_webm);

        pushButton_convert_mkv_to_webm = new QPushButton(tab_5);
        pushButton_convert_mkv_to_webm->setObjectName("pushButton_convert_mkv_to_webm");
        pushButton_convert_mkv_to_webm->setEnabled(false);
        pushButton_convert_mkv_to_webm->setText(QString::fromUtf8(""));
        pushButton_convert_mkv_to_webm->setIcon(icon12);

        horizontalLayout_36->addWidget(pushButton_convert_mkv_to_webm);


        verticalLayout_27->addLayout(horizontalLayout_36);

        widget_convert_mkv_to_webm = new QWidget(tab_5);
        widget_convert_mkv_to_webm->setObjectName("widget_convert_mkv_to_webm");
        widget_convert_mkv_to_webm->setStyleSheet(QString::fromUtf8(""));
        horizontalLayout_38 = new QHBoxLayout(widget_convert_mkv_to_webm);
        horizontalLayout_38->setSpacing(0);
        horizontalLayout_38->setObjectName("horizontalLayout_38");
        horizontalLayout_38->setContentsMargins(0, 0, 0, 0);
        label_convert_mkv_to_webm = new QLabel(widget_convert_mkv_to_webm);
        label_convert_mkv_to_webm->setObjectName("label_convert_mkv_to_webm");
        sizePolicy2.setHeightForWidth(label_convert_mkv_to_webm->sizePolicy().hasHeightForWidth());
        label_convert_mkv_to_webm->setSizePolicy(sizePolicy2);
        label_convert_mkv_to_webm->setText(QString::fromUtf8("Please select a file"));

        horizontalLayout_38->addWidget(label_convert_mkv_to_webm, 0, Qt::AlignHCenter);


        verticalLayout_27->addWidget(widget_convert_mkv_to_webm);


        gridLayout_5->addLayout(verticalLayout_27, 5, 3, 1, 1);

        verticalLayout_26 = new QVBoxLayout();
        verticalLayout_26->setSpacing(2);
        verticalLayout_26->setObjectName("verticalLayout_26");
        verticalLayout_26->setContentsMargins(-1, 0, -1, -1);
        horizontalLayout_30 = new QHBoxLayout();
        horizontalLayout_30->setObjectName("horizontalLayout_30");
        lineEdit_convert_mkv_repair = new QLineEdit(tab_5);
        lineEdit_convert_mkv_repair->setObjectName("lineEdit_convert_mkv_repair");
        lineEdit_convert_mkv_repair->setText(QString::fromUtf8(""));
        lineEdit_convert_mkv_repair->setReadOnly(true);

        horizontalLayout_30->addWidget(lineEdit_convert_mkv_repair);

        toolButton_convert_dialog_mkv_repair = new QToolButton(tab_5);
        toolButton_convert_dialog_mkv_repair->setObjectName("toolButton_convert_dialog_mkv_repair");
        toolButton_convert_dialog_mkv_repair->setText(QString::fromUtf8("..."));

        horizontalLayout_30->addWidget(toolButton_convert_dialog_mkv_repair);

        pushButton_convert_mkv_repair = new QPushButton(tab_5);
        pushButton_convert_mkv_repair->setObjectName("pushButton_convert_mkv_repair");
        pushButton_convert_mkv_repair->setEnabled(false);
        pushButton_convert_mkv_repair->setText(QString::fromUtf8(""));
        pushButton_convert_mkv_repair->setIcon(icon12);

        horizontalLayout_30->addWidget(pushButton_convert_mkv_repair);


        verticalLayout_26->addLayout(horizontalLayout_30);

        widget_convert_mkv_repair = new QWidget(tab_5);
        widget_convert_mkv_repair->setObjectName("widget_convert_mkv_repair");
        widget_convert_mkv_repair->setStyleSheet(QString::fromUtf8(""));
        horizontalLayout_31 = new QHBoxLayout(widget_convert_mkv_repair);
        horizontalLayout_31->setSpacing(0);
        horizontalLayout_31->setObjectName("horizontalLayout_31");
        horizontalLayout_31->setContentsMargins(0, 0, 0, 0);
        label_convert_mkv_repair = new QLabel(widget_convert_mkv_repair);
        label_convert_mkv_repair->setObjectName("label_convert_mkv_repair");
        sizePolicy2.setHeightForWidth(label_convert_mkv_repair->sizePolicy().hasHeightForWidth());
        label_convert_mkv_repair->setSizePolicy(sizePolicy2);
        label_convert_mkv_repair->setText(QString::fromUtf8("Please select a file"));

        horizontalLayout_31->addWidget(label_convert_mkv_repair, 0, Qt::AlignHCenter);


        verticalLayout_26->addWidget(widget_convert_mkv_repair);


        gridLayout_5->addLayout(verticalLayout_26, 8, 3, 1, 1);

        verticalSpacer_12 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_5->addItem(verticalSpacer_12, 6, 3, 1, 1);

        label_12 = new QLabel(tab_5);
        label_12->setObjectName("label_12");
        label_12->setMaximumSize(QSize(22, 15));
        label_12->setText(QString::fromUtf8(""));
        label_12->setPixmap(QPixmap(QString::fromUtf8(":/pictures/convert/convertTo.png")));
        label_12->setScaledContents(true);

        gridLayout_5->addWidget(label_12, 5, 1, 1, 1);

        label_13 = new QLabel(tab_5);
        label_13->setObjectName("label_13");
        label_13->setFont(font1);
        label_13->setText(QString::fromUtf8("webm"));

        gridLayout_5->addWidget(label_13, 5, 2, 1, 1);

        label_9 = new QLabel(tab_5);
        label_9->setObjectName("label_9");
        label_9->setFont(font1);
        label_9->setText(QString::fromUtf8("GIF"));

        gridLayout_5->addWidget(label_9, 3, 2, 1, 1);

        label_8 = new QLabel(tab_5);
        label_8->setObjectName("label_8");
        label_8->setMaximumSize(QSize(22, 15));
        label_8->setText(QString::fromUtf8(""));
        label_8->setPixmap(QPixmap(QString::fromUtf8(":/pictures/convert/convertTo.png")));
        label_8->setScaledContents(true);

        gridLayout_5->addWidget(label_8, 3, 1, 1, 1);

        label_7 = new QLabel(tab_5);
        label_7->setObjectName("label_7");
        label_7->setFont(font1);
        label_7->setText(QString::fromUtf8("mkv"));

        gridLayout_5->addWidget(label_7, 3, 0, 1, 1);

        label_6 = new QLabel(tab_5);
        label_6->setObjectName("label_6");
        label_6->setFont(font1);
        label_6->setText(QString::fromUtf8("mp4"));

        gridLayout_5->addWidget(label_6, 1, 2, 1, 1);

        label_5 = new QLabel(tab_5);
        label_5->setObjectName("label_5");
        label_5->setMaximumSize(QSize(22, 15));
        label_5->setText(QString::fromUtf8(""));
        label_5->setPixmap(QPixmap(QString::fromUtf8(":/pictures/convert/convertTo.png")));
        label_5->setScaledContents(true);

        gridLayout_5->addWidget(label_5, 1, 1, 1, 1);

        label_3 = new QLabel(tab_5);
        label_3->setObjectName("label_3");
        label_3->setFont(font1);
        label_3->setText(QString::fromUtf8("mkv"));

        gridLayout_5->addWidget(label_3, 1, 0, 1, 1);

        label_11 = new QLabel(tab_5);
        label_11->setObjectName("label_11");
        label_11->setFont(font1);
        label_11->setText(QString::fromUtf8("mkv"));

        gridLayout_5->addWidget(label_11, 5, 0, 1, 1);

        label_10 = new QLabel(tab_5);
        label_10->setObjectName("label_10");
        label_10->setFont(font1);
        label_10->setText(QString::fromUtf8("mkv"));

        gridLayout_5->addWidget(label_10, 8, 0, 1, 1);


        verticalLayout_23->addLayout(gridLayout_5);

        verticalSpacer_10 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_23->addItem(verticalSpacer_10);

        tabWidgetConvert->addTab(tab_5, icon3, QString());
        tabWidgetConvert->setTabText(tabWidgetConvert->indexOf(tab_5), QString::fromUtf8(""));

        verticalLayout_21->addWidget(tabWidgetConvert);

        tabWidgetSideBar->addTab(tab_3, QString());
        tabWidgetSideBar->setTabText(tabWidgetSideBar->indexOf(tab_3), QString::fromUtf8(""));
        tabSidebarLog = new QWidget();
        tabSidebarLog->setObjectName("tabSidebarLog");
        verticalLayout_4 = new QVBoxLayout(tabSidebarLog);
        verticalLayout_4->setObjectName("verticalLayout_4");
        verticalLayout_4->setContentsMargins(0, 0, 0, 0);
        tabWidgetLog = new QTabWidget(tabSidebarLog);
        tabWidgetLog->setObjectName("tabWidgetLog");
        tabWidgetLog->setIconSize(QSize(48, 48));
        tabLog = new QWidget();
        tabLog->setObjectName("tabLog");
        verticalLayout_9 = new QVBoxLayout(tabLog);
        verticalLayout_9->setObjectName("verticalLayout_9");
        label = new QLabel(tabLog);
        label->setObjectName("label");
        label->setFont(font1);
        label->setText(QString::fromUtf8("Log"));

        verticalLayout_9->addWidget(label, 0, Qt::AlignHCenter);

        line_8 = new QFrame(tabLog);
        line_8->setObjectName("line_8");
        line_8->setStyleSheet(QString::fromUtf8("color: rgb(200, 200, 200);"));
        line_8->setFrameShadow(QFrame::Plain);
        line_8->setFrameShape(QFrame::Shape::HLine);

        verticalLayout_9->addWidget(line_8);

        textBrowser = new QTextBrowser(tabLog);
        textBrowser->setObjectName("textBrowser");

        verticalLayout_9->addWidget(textBrowser);

        horizontalLayout_12 = new QHBoxLayout();
        horizontalLayout_12->setObjectName("horizontalLayout_12");
        horizontalSpacer_6 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_12->addItem(horizontalSpacer_6);

        pushButton_log_openfolder = new QPushButton(tabLog);
        pushButton_log_openfolder->setObjectName("pushButton_log_openfolder");
        pushButton_log_openfolder->setFont(font);

        horizontalLayout_12->addWidget(pushButton_log_openfolder);

        pushButton_log_refresh = new QPushButton(tabLog);
        pushButton_log_refresh->setObjectName("pushButton_log_refresh");
        pushButton_log_refresh->setFont(font);
        pushButton_log_refresh->setText(QString::fromUtf8("Refresh"));

        horizontalLayout_12->addWidget(pushButton_log_refresh);


        verticalLayout_9->addLayout(horizontalLayout_12);

        tabWidgetLog->addTab(tabLog, icon4, QString());
        tabWidgetLog->setTabText(tabWidgetLog->indexOf(tabLog), QString::fromUtf8(""));

        verticalLayout_4->addWidget(tabWidgetLog);

        tabWidgetSideBar->addTab(tabSidebarLog, QString());
        tabWidgetSideBar->setTabText(tabWidgetSideBar->indexOf(tabSidebarLog), QString::fromUtf8(""));

        horizontalLayout_13->addWidget(tabWidgetSideBar);


        verticalLayout->addLayout(horizontalLayout_13);

        formMainWindow_wl->setCentralWidget(centralwidget);

        retranslateUi(formMainWindow_wl);

        tabWidgetSideBar->setCurrentIndex(4);
        tabWidgetScreencast->setCurrentIndex(0);
        tabWidgetCamera->setCurrentIndex(0);
        tabWidgetSnapshot->setCurrentIndex(0);
        tabWidgetConvert->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(formMainWindow_wl);
    } // setupUi

    void retranslateUi(QMainWindow *formMainWindow_wl)
    {
        radioButtonScreencastWindow->setText(QCoreApplication::translate("formMainWindow_wl", "Window", nullptr));
        radioButtonScreencastArea->setText(QCoreApplication::translate("formMainWindow_wl", "Area", nullptr));
#if QT_CONFIG(tooltip)
        toolButtonScreencastAreaReset->setToolTip(QCoreApplication::translate("formMainWindow_wl", "Reset", nullptr));
#endif // QT_CONFIG(tooltip)
        radioButtonScreencastFullscreen->setText(QCoreApplication::translate("formMainWindow_wl", "Fullscreen", nullptr));
#if QT_CONFIG(tooltip)
        help_screencast_audio->setToolTip(QCoreApplication::translate("formMainWindow_wl", "Help", nullptr));
#endif // QT_CONFIG(tooltip)
        labelAudioCodec->setText(QCoreApplication::translate("formMainWindow_wl", "Audiocodec", nullptr));
#if QT_CONFIG(tooltip)
        toolButtonSeparatedAudioTracksReset->setToolTip(QCoreApplication::translate("formMainWindow_wl", "Reset", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        help_screencast_audiocodec->setToolTip(QCoreApplication::translate("formMainWindow_wl", "Help", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        help_screencast_nomousecursor->setToolTip(QCoreApplication::translate("formMainWindow_wl", "Help", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        toolButtonOpenh264Reset->setToolTip(QCoreApplication::translate("formMainWindow_wl", "Reset", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        help_screencast_format->setToolTip(QCoreApplication::translate("formMainWindow_wl", "Help", nullptr));
#endif // QT_CONFIG(tooltip)
        labelVideoCodec->setText(QCoreApplication::translate("formMainWindow_wl", "Videocodec", nullptr));
        labelFormat->setText(QCoreApplication::translate("formMainWindow_wl", "Format", nullptr));
#if QT_CONFIG(tooltip)
        toolButtonFramesReset->setToolTip(QCoreApplication::translate("formMainWindow_wl", "Reset", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        help_screencast_frames->setToolTip(QCoreApplication::translate("formMainWindow_wl", "Help", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxMouseCursorOnOff->setText(QCoreApplication::translate("formMainWindow_wl", "Do not record mouse cursor", nullptr));
        labelFrames->setText(QCoreApplication::translate("formMainWindow_wl", "Frames", nullptr));
#if QT_CONFIG(tooltip)
        help_screencast_videocodec->setToolTip(QCoreApplication::translate("formMainWindow_wl", "Help", nullptr));
#endif // QT_CONFIG(tooltip)
        labelScreencastCountdownText->setText(QCoreApplication::translate("formMainWindow_wl", "Countdown", nullptr));
        help_screencast_countdown->setText(QCoreApplication::translate("formMainWindow_wl", "Help", nullptr));
        label_29->setText(QCoreApplication::translate("formMainWindow_wl", "Frames", nullptr));
        label_19->setText(QCoreApplication::translate("formMainWindow_wl", "Free disk space:", nullptr));
        label_27->setText(QCoreApplication::translate("formMainWindow_wl", "Audiocodec", nullptr));
        label_31->setText(QCoreApplication::translate("formMainWindow_wl", "Format", nullptr));
        label_33->setText(QCoreApplication::translate("formMainWindow_wl", "Record Time:", nullptr));
        label_20->setText(QCoreApplication::translate("formMainWindow_wl", "Video size:", nullptr));
        label_28->setText(QCoreApplication::translate("formMainWindow_wl", "Videocodec", nullptr));
        label_18->setText(QCoreApplication::translate("formMainWindow_wl", "Information", nullptr));
        LabelVideoPath->setText(QCoreApplication::translate("formMainWindow_wl", "Videopath", nullptr));
#if QT_CONFIG(tooltip)
        toolButtonVideoPathReset->setToolTip(QCoreApplication::translate("formMainWindow_wl", "Reset", nullptr));
#endif // QT_CONFIG(tooltip)
        comboBoxOnlineHelp->setItemText(0, QCoreApplication::translate("formMainWindow_wl", "Automatically", nullptr));

        checkBoxResetAtNextStart->setText(QCoreApplication::translate("formMainWindow_wl", "Reset all settings at the next start", nullptr));
        checkBoxShowInSystray->setText(QCoreApplication::translate("formMainWindow_wl", "Show in systray", nullptr));
        label_34->setText(QCoreApplication::translate("formMainWindow_wl", "Second wait before recording", nullptr));
        checkBoxMinimizedWhenRecordingStarts->setText(QCoreApplication::translate("formMainWindow_wl", "Minimized when recording starts", nullptr));
        label_22->setText(QCoreApplication::translate("formMainWindow_wl", "Available", nullptr));
        label_23->setText(QCoreApplication::translate("formMainWindow_wl", "Not available", nullptr));
        pushButtonLicense->setText(QCoreApplication::translate("formMainWindow_wl", "Copyright and license from pictures", nullptr));
        pushButtonImages->setText(QCoreApplication::translate("formMainWindow_wl", "Create images of tabs ", nullptr));
        pushButtonCiscoLicense->setText(QCoreApplication::translate("formMainWindow_wl", "License information", nullptr));
        radioButton_cisco_on->setText(QCoreApplication::translate("formMainWindow_wl", "ON", nullptr));
        radioButton_cisco_off->setText(QCoreApplication::translate("formMainWindow_wl", "OFF", nullptr));
        pushButtonStart->setText(QCoreApplication::translate("formMainWindow_wl", "Start", nullptr));
        pushButtonStop->setText(QCoreApplication::translate("formMainWindow_wl", "Stop", nullptr));
        pushButtonPause->setText(QCoreApplication::translate("formMainWindow_wl", "Pause", nullptr));
        pushButtonContinue->setText(QCoreApplication::translate("formMainWindow_wl", "Continue", nullptr));
        pushButtonOpenfolder->setText(QCoreApplication::translate("formMainWindow_wl", "Folder", nullptr));
        pushButtonSnapshot_2->setText(QCoreApplication::translate("formMainWindow_wl", "Snapshot", nullptr));
        pushButtonSnapshotOpenFolder_2->setText(QCoreApplication::translate("formMainWindow_wl", "Folder", nullptr));
        label_4->setText(QCoreApplication::translate("formMainWindow_wl", "Camera", nullptr));
#if QT_CONFIG(tooltip)
        help_camera_camera->setToolTip(QCoreApplication::translate("formMainWindow_wl", "Help", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxCameraInvert->setText(QCoreApplication::translate("formMainWindow_wl", "Invert", nullptr));
        checkBoxCameraGray->setText(QCoreApplication::translate("formMainWindow_wl", "Gray", nullptr));
        checkBoxCameraMono->setText(QCoreApplication::translate("formMainWindow_wl", "Black-and-white", nullptr));
        checkBoxCameraOnOff->setText(QCoreApplication::translate("formMainWindow_wl", "Camera", nullptr));
        checkBoxCameraMirrorVertical->setText(QCoreApplication::translate("formMainWindow_wl", "Flip vertical", nullptr));
        checkBoxCameraMirrorHorizontal->setText(QCoreApplication::translate("formMainWindow_wl", "Flip horizontal", nullptr));
        checkBoxCameraWindowFrame->setText(QCoreApplication::translate("formMainWindow_wl", "Remove window frame", nullptr));
#if QT_CONFIG(tooltip)
        toolButtonSnapshotFormatsReset->setToolTip(QCoreApplication::translate("formMainWindow_wl", "Reset", nullptr));
#endif // QT_CONFIG(tooltip)
        label_57->setText(QCoreApplication::translate("formMainWindow_wl", "Format", nullptr));
        label_60->setText(QCoreApplication::translate("formMainWindow_wl", "Seconds wait before recording", nullptr));
#if QT_CONFIG(tooltip)
        toolButtonSnapshotSecondsWaitBeforeRecordingReset->setToolTip(QCoreApplication::translate("formMainWindow_wl", "Reset", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxSnapshotHideBeforeRecording->setText(QCoreApplication::translate("formMainWindow_wl", "Hide this window", nullptr));
#if QT_CONFIG(tooltip)
        toolButtonSnapshotHideBeforeRecordingReset->setToolTip(QCoreApplication::translate("formMainWindow_wl", "Reset", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxSnapshotShowBallonInSystray->setText(QCoreApplication::translate("formMainWindow_wl", "Show in systray", nullptr));
        pushButtonSnapshotOpenFolder->setText(QCoreApplication::translate("formMainWindow_wl", "Folder", nullptr));
        pushButtonSnapshot->setText(QCoreApplication::translate("formMainWindow_wl", "Snapshot", nullptr));
        pushButton_log_openfolder->setText(QCoreApplication::translate("formMainWindow_wl", "Folder", nullptr));
        (void)formMainWindow_wl;
    } // retranslateUi

};

namespace Ui {
    class formMainWindow_wl: public Ui_formMainWindow_wl {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_FORMMAINWINDOW_WL_H
